##### Naked Mole Rat microbiome #####

# libraries
library(ggplot2)
library(phyloseq)
library(dada2)
library(vegan)
library(lme4)
library(lmerTest)
library(DESeq2)
library(ALDEx2)
library(ggmap)
library(genefilter)
library(Biostrings)
library(ape)
library(ade4)
library(Hmisc)
library(plyr)
library(RColorBrewer)
library(phytools)
library(dplyr)
library(reshape2)
library(broom)
library(seqinr)
library(psych)
library(picante)
library(ade4)
library(gplots)
library(corrplot)
library(SpiecEasi)
library(igraph)
library(afex)
library(gdata)

# functions #
st.err <- function(x) {
  sd(x)/sqrt(length(x))
}
is.finite.data.frame <- function(obj){
  sapply(obj,FUN = function(x) all(is.finite(x)))
} # Thanks joran @ stack exchange

rel.abund <- function(x){x / sum(x)}

# Define zero-tolerant function for calculating geometric means (courtesy of P.J. McMurdie) #
gm_mean = function(x, na.rm=TRUE){
  exp(sum(log(x[x > 0]), na.rm=na.rm) / length(x))
}

# ggplot theme #
# *** Note: all figures made in R, arranged in Inkscape or Illustrator #
theme.gg<-theme(panel.background = element_rect(fill = "transparent", 
                colour = NA), plot.background = element_rect(colour = 'NA',                               fill = 'transparent'),panel.grid.major=element_line(color=NA),
                axis.line=element_line(size=1.2,color="black"),
                axis.ticks=element_line(color="black"),
                axis.text=element_text(color="black",size=26),
                axis.title=element_text(color="black",size=30),
                panel.grid.minor = element_line(colour = NA),
                legend.text=element_text(size=17),legend.key=element_rect(fill="white"),
                legend.title=element_text(size=18,face="bold"),
                axis.text.x=element_text(angle=60,size=26,vjust=0.5),
                panel.border = element_rect(colour = "black", fill=NA, size=3),
                legend.position = "none")

theme.gg.leg<-theme(panel.background = element_rect(fill = "transparent", 
                    colour = NA), plot.background = element_rect(colour = 'NA',                                                                                                 fill = 'transparent'),panel.grid.major=element_line(color=NA),
                    axis.line=element_line(size=1.2,color="black"),
                    axis.ticks=element_line(color="black"),
                    axis.text=element_text(color="black",size=26),
                    axis.title=element_text(color="black",size=30),
                    panel.grid.minor = element_line(colour = NA),
                    legend.text=element_text(size=17),legend.key=element_rect(fill="white"),
                    legend.title=element_text(size=18,face="bold"),
                    axis.text.x=element_text(angle=60,size=26,vjust=0.5),
                    panel.border = element_rect(colour = "black", fill=NA, size=3))

theme.gg.blankx<-theme(panel.background = element_rect(fill = "transparent", 
                colour = NA), plot.background = element_rect(colour = 'NA',                               fill = 'transparent'),panel.grid.major=element_line(color=NA),
                axis.line=element_line(size=1.2,color="black"),
                axis.ticks=element_line(color="black"),
                axis.text=element_text(color="black",size=26),
                axis.title=element_text(color="black",size=30),
                panel.grid.minor = element_line(colour = NA),
                legend.text=element_text(size=17),legend.key=element_rect(fill="white"),
                legend.title=element_text(size=18,face="bold"),
                axis.title.x=element_blank(),
                axis.text.x=element_blank(),
                panel.border = element_rect(colour = "black", fill=NA, size=3),
                legend.position = "none")

# bacterial phyla colours

phylum.colors <- c("Verrucomicrobia"="#483D8B", "Epsilonbacteraeota"="#CDB79E", "Synergistetes"="#B22222", 
                   "Firmicutes"="#E69F00", "Planctomycetes"="#CC9966",
                   "Bacteroidetes"="#56B4E9", "Fibrobacteres"="#009E73", "Proteobacteria"="#F0E68C", 
                   "Cyanobacteria/Chloroplast"="#548B54", "Spirochaetes"="#CC79A7","Cyanobacteria"="#8B4726",
                   "Low Abundance"="#000000","candidate_division_WPS-2"="#1E90FF")

pair.colors <- c("pair1"="#a6cee3", "pair2"="#1f78b4", "pair3"="#b2df8a","pair4"="#33a02c",
                 "pair5"="#fb9a99","pair6"="#e31a1c", "pair7"="#fdbf6f", "pair8"="#ff7f00",
                 "pair9"="#cab2d6", "pair10"="#6a3d9a")

colony.colors <- c("Elizabeth"="#e41a1c", "Fenty"="#377eb8", "Ichabod"="#4daf4a",
                   "Lucy"="#984ea3", "Macbeth"="#ff7f00", "Xena"="#ffff33", "mouse"="#636363")

caste.colors <- c("worker"="#1b9e77","soldier"="#d95f02", "disperser"="#7570b3",
                  "breeding_male"="#e7298a", "queen"="#66a61e", "mouse"="#636363")

seqtab.total<-readRDS("~dada2/nmrm.seqtab.nochim_FULL.rds")
bac.tree<-read.tree(file= "~Phylogeny/nmrm.full.tre")
samp.names<-as.data.frame(sapply(strsplit(rownames(seqtab.total), "-"), `[`))
meta.data<-read.csv("~nmrm_metadata.csv")
meta.data$date <- as.Date(meta.data$date, format = "%d-%b-%y")
meta.data$rank<-as.numeric(meta.data$rank)
meta.data<-meta.data[order(match(meta.data[,1],samp.names[,1])),] # reorder meta data to match ASV table 
rownames(meta.data) <- rownames(seqtab.total) # yes, they match 

#taxa<-readRDS("~dada2/taxa_Jan14.rds") # RDP classification
taxa<-readRDS("~dada2/taxaSilva_nmrm.rds") # RDP classification

ps <- phyloseq(otu_table(seqtab.total, taxa_are_rows=FALSE), # 5358 ASVs
               sample_data(meta.data), 
               tax_table(taxa),
               phy_tree(bac.tree))

#saveRDS(ps,"~dada2/phyloseq_object_nmrm.rds")

colnames(tax_table(ps)) = c("Domain", "Phylum", "Class", "Order", "Family", "Genus")
table(tax_table(ps)[, "Phylum"], exclude = NULL) #1333 in Archaea or unknown
table(tax_table(ps)[, "Domain"], exclude = NULL) #19184 in unknown phylum
table(tax_table(ps)[, "Class"], exclude = NULL) #408 in chloroplast
table(tax_table(ps)[, "Order"], exclude = NULL) #408 in chloroplast
table(tax_table(ps)[, "Family"], exclude = NULL) #408 in chloroplast

#### 1) Data clean-up ####
# remove Archaea, unknowns, chloroplasts #
ps1 = subset_taxa(ps, Domain == "Bacteria") # removes 70 ASVs
ps1 

ps2 <- subset_taxa(ps1, !is.na(Phylum)) # removes 689
ps2 

bad.order<-c("Chloroplast")
ps3 = subset_taxa(ps2, !Order %in% bad.order) # removes 1
ps3 

bad.family<-c("Mitochondria")
ps4 = subset_taxa(ps3, !Family %in% bad.family) # removes 4
ps4 # left with 4594 ASVs, 6,223,376 reads, 38415 reads per sample +/- 10818 (st. dev.)

sum(taxa_sums(ps4))/sum(taxa_sums(ps)) # 98% of reads retained after removing unwanted

# add usable reads to meta data
sample_data(ps4)$UsableReads<-sample_sums(ps4)
# add species and breeder status to meta data
sample_data(ps4)$spe<-ifelse(sample_data(ps4)$colony=="mouse","mouse","nmr")
sample_data(ps4)$ind.id<-interaction(sample_data(ps4)$colony,sample_data(ps4)$sex)
sample_data(ps4)$rep.state<-ifelse(sample_data(ps4)$subcaste=="breeding_male" | sample_data(ps4)$subcaste=="queen","breeder","nonbreeder")

# Identify contaminants #
library(decontam)
sample_data(ps4)$is.neg <- sample_data(ps4)$experiment == "control"
contamdf.prev <- isContaminant(ps4, method="prevalence", neg="is.neg")
table(contamdf.prev$contaminant)
head(which(contamdf.prev$contaminant))

ASV_map<-as.data.frame(taxa_names(ps4))
ASV_map$ASVid<-paste("ASV",1:nrow(ASV_map),sep="_")
taxa_names(ps4)<-ASV_map$ASVid
saveRDS(ASV_map,"~/Dropbox/NMRM/ASV_map.rds")
write.csv(ASV_map,"~/Dropbox/NMRM/ASV_map.csv")

#### 2) Alpha diversity analysis ####
alpha.1<-as.data.frame(estimate_richness(ps4,measures=c("Observed","Shannon","InvSimpson")))
alpha.1.sd<-as(sample_data(ps4),'data.frame')
alpha.2<-cbind(alpha.1.sd,alpha.1)
alpha.2$E2<-alpha.2$InvSimpson/alpha.2$Observed
alpha.2$log.reads<-log(alpha.2$UsableReads)
mean(alpha.2[-c(70:72),12])
sd(alpha.2[-c(70:72),12])
# remove control samples #
alpha.2<-alpha.2[-c(70:72),]

plot(Observed~samp_weight,data=alpha.2)
plot(Observed~log.reads,data=alpha.2)
plot(InvSimpson~samp_weight,data=alpha.2)
plot(InvSimpson~log.reads,data=alpha.2)
plot(E2~samp_weight,data=alpha.2)
plot(E2~log.reads,data=alpha.2)
# strong relationship between reads/sample weight and observed, but not InvSimp or E2

# all diversity measures look fairly normal #
hist(alpha.2$Observed)
hist(alpha.2$InvSimpson)
hist(alpha.2$E2)

ic.alpha<-alpha.2[alpha.2$experiment=="IC",] # In Colony samples
ic.alpha.nm<-ic.alpha[ic.alpha$colony != "mouse",] # remove mice
ic.alpha<-droplevels(ic.alpha)
ic.alpha.nm<-droplevels(ic.alpha.nm)
p.alpha<-droplevels(alpha.2[alpha.2$experiment=="P",])

plot(Observed~date,data=ic.alpha.nm)
summary(lm(Observed~date,data=ic.alpha.nm)) # no effect of sampling date on diversity
plot(UsableReads~colony,data=ic.alpha) # uniform read depth across colonies and subcastes
plot(UsableReads~subcaste,data=ic.alpha)

## Table of sample numbers #
write.csv(as.data.frame.matrix(xtabs(~colony+subcaste,data=ic.alpha)),"~Manuscript/IC.sample.numbers.csv") # P8.female and P9.male missing T2
write.csv(as.data.frame.matrix(xtabs(~colony+subcaste,data=p.alpha)),"~Manuscript/P.sample.numbers.csv") # P8.female and P9.male missing T2

xtabs(~subcaste,data=ic.alpha)

plot(rank~weight,data=ic.alpha.nm)
plot(rank~subcaste,data=ic.alpha.nm)
cor.test(ic.alpha.nm$rank,ic.alpha.nm$weight)

#### In colony experiment ####
# check for multicollinearity between age, rank, weight:
#Variance inflation factors
#rank   2.267917
#age    1.404031
#weight 2.855857
# via: http://highstat.com/Books/BGS/GAMM/RCodeP2/HighstatLibV6.R

# Question 1) Do colonies, social groups, and sexes vary in diversity?
m1.obs<-(lm(Observed ~ subcaste+colony+sex+weight+rank+age+log.reads+samp_weight, data = ic.alpha.nm))
car::Anova(m1.obs, type="II") # sig. effect of 
anova(m1.obs)
TukeyHSD(x=m1.obs, 'colony', conf.level=0.95)

m1.invs<-(lm(InvSimpson ~ subcaste+colony+sex+weight+rank+age+log.reads+samp_weight, data = ic.alpha.nm))
car::Anova(m1.invs, type="II") 
TukeyHSD(x=m1.invs, 'colony', conf.level=0.95)
anova(m1.invs)

ggplot(data=ic.alpha.nm, aes(x=colony, y=InvSimpson,color=colony)) +
  geom_jitter(alpha=.5,width=.3,size=5)+
  scale_color_manual(values=colony.colors) +
  scale_y_continuous(breaks=seq(0,100,10)) +
  theme_classic()

m1.e2<-(lm(E2 ~ subcaste+colony+sex+weight+rank+age+log.reads+samp_weight, data = ic.alpha.nm))
car::Anova(m1.e2, type="II") 
TukeyHSD(x=m1.invs, 'colony', conf.level=0.95)
anova(m1.e2)

# Question 2) Do colony, subcaste, or sex interact to affect diversity? #
# need to remove Queen and Breeding Males #
ic.alpha.2<-ic.alpha.nm[ic.alpha.nm$subcaste!="breeding_male" & ic.alpha.nm$subcaste!="queen",]
ic.alpha.2<-droplevels(ic.alpha.2)

m2.obs<-(lm(Observed ~ subcaste+colony+subcaste:colony+sex:colony+sex:subcaste+sex+weight+age+rank+
        log.reads+samp_weight, data = ic.alpha.2))
car::Anova(m2.obs, type="III") # no sig interactions, remove then run type II
m2.obs<-(lm(Observed ~ subcaste+colony++sex+weight+age+rank+
              log.reads+samp_weight, data = ic.alpha.2))
car::Anova(m2.obs, type="II")


m2.invs<-(lm(InvSimpson ~ subcaste+colony+sex+subcaste:colony+sex:colony+sex:subcaste+weight+age+rank+
               log.reads+samp_weight, data = ic.alpha.2))
car::Anova(m2.invs, type="III") 
m2.invs<-(lm(InvSimpson ~ subcaste+colony++sex+weight+age+rank+
              log.reads+samp_weight, data = ic.alpha.2))
car::Anova(m2.invs, type="II")

ggplot(data=ic.alpha.2, aes(x=colony, y=InvSimpson,color=colony)) +
  geom_jitter(alpha=.5,width=.3,size=5)+
  scale_color_manual(values=colony.colors) +
  scale_y_continuous(breaks=seq(0,100,10)) +
  theme_classic()

m2.e2<-(aov(E2 ~ subcaste+colony+sex+subcaste:colony+sex:colony+sex:subcaste+weight+age+rank+
               log.reads+samp_weight, data = ic.alpha.2))
car::Anova(m2.e2, type="III") 
m2.e2<-(lm(E2 ~ subcaste+colony++sex+weight+age+rank+
               log.reads+samp_weight, data = ic.alpha.2))
car::Anova(m2.e2, type="II")

# Question 3) Do species vary in alpha diversity?
m1.obs<-(aov(Observed ~ spe*sex + log.reads+samp_weight, data = ic.alpha))
car::Anova(m1.obs, type="III") # sig. effect of 

m1.Shannon<-(aov(Shannon ~ spe*sex + log.reads+samp_weight, data = ic.alpha))
car::Anova(m1.Shannon, type="III") # sig. effect of 

m1.invsimp<-(aov(InvSimpson ~ spe*sex + log.reads+samp_weight, data = ic.alpha))
car::Anova(m1.invsimp, type="III") # sig. effect of 
TukeyHSD(x=m1.invsimp, 'sex', conf.level=0.95)

m1.e2<-(lm(E2 ~ spe*sex + log.reads+samp_weight, data = ic.alpha))
car::Anova(m1.e2, type="III") # sig. effect of 

xtabs(~sex.spe,data=ic.alpha)

#### Paired experiment ####
# Question 1) Does diversity go up after separation and sexual maturity?
# paired t-test T1 versus T2, T2 versus T3, T1 versus T3?
xtabs(~ind.id+subcaste,data=p.alpha) # P8.female and P9.male missing T2

# need to get columns of just T1, T2, T3 diversity #
t1.div<-p.alpha[p.alpha$subcaste=="T1",c(3,13:17)]
colnames(t1.div)<-paste(colnames(t1.div),"1",sep=".")
t2.div<-p.alpha[p.alpha$subcaste=="T2",c(3,13:17)]
colnames(t2.div)<-paste(colnames(t2.div),"2",sep=".")
t3.div<-p.alpha[p.alpha$subcaste=="T3",c(3,13:17)]
colnames(t3.div)<-paste(colnames(t3.div),"3",sep=".")

t13<-merge(t1.div,t3.div,by.x="ind.id.1",by.y="ind.id.3")
t123<-merge(t13,t2.div,by.x="ind.id.1",by.y="ind.id.2",all=T)

t.test(t123$Observed.1,t123$Observed.2, paired=T, alternative = "two.sided")
t.test(t123$Observed.1,t123$Observed.3, paired=T, alternative = "two.sided")
t.test(t123$Observed.2,t123$Observed.3, paired=T, alternative = "two.sided")

t.test(t123$InvSimpson.1,t123$InvSimpson.2, paired=T, alternative = "two.sided")
t.test(t123$InvSimpson.1,t123$InvSimpson.3, paired=T, alternative = "two.sided")
t.test(t123$InvSimpson.2,t123$InvSimpson.3, paired=T, alternative = "two.sided")

t.test(t123$E2.1,t123$E2.2, paired=T, alternative = "two.sided")
t.test(t123$E2.1,t123$E2.3, paired=T, alternative = "two.sided")
t.test(t123$E2.2,t123$E2.3, paired=T, alternative = "two.sided")

# diversity does not change 
# what about variance? #

leveneTest(Observed ~ subcaste, data = p.alpha)
leveneTest(InvSimpson ~ subcaste, data = p.alpha)
leveneTest(E2 ~ subcaste, data = p.alpha)

# Question 2) do individuals within a pair resemble one another more over time?
# paired t-test on difference in diversity between individuals within a pair?
# split data frame into male and female #
t123.fem<-t123[c(1:10),]
t123.mal<-t123[c(11:20),]
colnames(t123.mal)<-paste(colnames(t123.mal),"male",sep=".")
t123.split<-cbind(t123.fem,t123.mal)

t123.split$t1.obs.diff<-t123.split$Observed.1-t123.split$Observed.1.male
t123.split$t2.obs.diff<-t123.split$Observed.2-t123.split$Observed.2.male
t123.split$t3.obs.diff<-t123.split$Observed.3-t123.split$Observed.3.male

t.test(t123.split$t1.obs.diff,t123.split$t2.obs.diff,paired=T,alternative="two.sided")
t.test(t123.split$t1.obs.diff,t123.split$t3.obs.diff,paired=T,alternative="two.sided")
t.test(t123.split$t2.obs.diff,t123.split$t3.obs.diff,paired=T,alternative="two.sided")

t123.split$t1.inv.diff<-t123.split$InvSimpson.1-t123.split$InvSimpson.1.male
t123.split$t2.inv.diff<-t123.split$InvSimpson.2-t123.split$InvSimpson.2.male
t123.split$t3.inv.diff<-t123.split$InvSimpson.3-t123.split$InvSimpson.3.male

t.test(t123.split$t1.inv.diff,t123.split$t2.inv.diff,paired=T,alternative="greater")
t.test(t123.split$t1.inv.diff,t123.split$t3.inv.diff,paired=T,alternative="greater")
t.test(t123.split$t2.inv.diff,t123.split$t3.inv.diff,paired=T,alternative="greater")

t123.split$t1.e2.diff<-t123.split$E2.1-t123.split$E2.1.male
t123.split$t2.e2.diff<-t123.split$E2.2-t123.split$E2.2.male
t123.split$t3.e2.diff<-t123.split$E2.3-t123.split$E2.3.male

t.test(t123.split$t1.e2.diff,t123.split$t2.e2.diff,paired=T,alternative="greater")
t.test(t123.split$t1.e2.diff,t123.split$t3.e2.diff,paired=T,alternative="greater")
t.test(t123.split$t2.e2.diff,t123.split$t3.e2.diff,paired=T,alternative="greater")

#### 2.1) Alpha diversity figures ####

ic.alpha$subcaste <- factor(ic.alpha$subcaste,
                                     levels = c("worker","soldier","disperser",
                                                "breeding_male","queen","mouse"),ordered = TRUE)
ic.alpha$colony <- factor(ic.alpha$colony,
                            levels = c("Xena","Lucy","Elizabeth","Macbeth","Fenty",
                                       "Ichabod","mouse"),ordered = TRUE)

ic.alpha.nm$subcaste <- factor(ic.alpha.nm$subcaste,
                            levels = c("worker","soldier","disperser",
                                       "breeding_male","queen"),ordered = TRUE)
ic.alpha.nm$colony <- factor(ic.alpha.nm$colony,
                          levels = c("Xena","Lucy","Elizabeth","Macbeth","Fenty",
                                     "Ichabod"),ordered = TRUE)


##### In colony ####
# Diversity by colony #
mean.alpha <- ic.alpha.nm %>% group_by(colony) %>% summarise_all(funs(mean))
mean.alpha<-as.data.frame(mean.alpha[,c(1,16:19)])
names(mean.alpha)<-c("colony","obs.mean","shan.mean","inv.mean","e2.mean")
ic.alpha.nm.sum<-merge(ic.alpha.nm,mean.alpha,by="colony",all=T)

pdf(file="~Manuscript/Figures/colony_invsimp.pdf",
    width=10,height=5,bg = "transparent")
ggplot(data=ic.alpha.nm.sum, aes(x=colony, y=InvSimpson,color=colony)) +
  geom_jitter(alpha=.5,width=.3,size=5)+
  geom_point(aes(x=colony, y=inv.mean),size=8) + 
  scale_color_manual(values=colony.colors) +
  scale_y_continuous(breaks=seq(0,100,10)) +
  theme.gg.blankx
dev.off()

pdf(file="~Manuscript/Figures/colony_obs.pdf",
    width=10,height=6,bg = "transparent")
ggplot(data=ic.alpha.nm.sum, aes(x=colony, y=Observed, color=colony)) +
  geom_jitter(alpha=.5,width=.3,size=5)+
  geom_point(aes(x=colony, y=obs.mean),size=8) + 
  scale_color_manual(values=colony.colors) +
  scale_y_continuous(breaks=seq(0,500,25)) +
  theme.gg 
dev.off()

pdf(file="~Manuscript/Figures/colony_e2.pdf",
    width=10,height=6,bg = "transparent")
ggplot(data=ic.alpha.nm.sum, aes(x=colony, y=E2,color=colony)) +
  geom_jitter(alpha=.5,width=.3,size=5)+
  geom_point(aes(x=colony, y=e2.mean),size=8) + 
  scale_color_manual(values=colony.colors) +
  scale_y_continuous(breaks=seq(0,0.5,0.05)) +
  theme.gg 
dev.off()

# Diversity by subcaste #
mean.alpha.caste <- ic.alpha.nm %>% group_by(subcaste) %>% summarise_all(funs(mean))
mean.alpha.caste<-as.data.frame(mean.alpha.caste[,c(1,16:19)])
names(mean.alpha.caste)<-c("subcaste","obs.mean","shan.mean","inv.mean","e2.mean")
ic.alpha.nm.sum<-merge(ic.alpha.nm,mean.alpha.caste,by="subcaste",all=T)

pdf(file="~Manuscript/Figures/subcaste_invsimp.pdf",
    width=10,height=5,bg = "transparent")
ggplot(data=ic.alpha.nm.sum, aes(x=subcaste, y=InvSimpson, color=subcaste)) +
  geom_jitter(alpha=.5,width=.3,size=5)+
  geom_point(aes(x=subcaste, y=inv.mean),size=8) + 
  scale_color_manual(values=caste.colors) +
  scale_y_continuous(breaks=seq(0,100,10)) +
  theme.gg.blankx 
dev.off()

pdf(file="~Manuscript/Figures/subcaste_obs.pdf",
    width=10,height=6,bg = "transparent")
ggplot(data=ic.alpha.nm.sum, aes(x=subcaste, y=Observed, color=subcaste)) +
  geom_jitter(alpha=.5,width=.3,size=5)+
  geom_point(aes(x=subcaste, y=obs.mean),size=8) + 
  scale_color_manual(values=caste.colors) +
  scale_y_continuous(breaks=seq(0,500,25)) +
  theme.gg 
dev.off()

pdf(file="~Manuscript/Figures/subcaste_e2.pdf",
    width=10,height=6,bg = "transparent")
ggplot(data=ic.alpha.nm.sum, aes(x=subcaste, y=E2, color=subcaste)) +
  geom_jitter(alpha=.5,width=.3,size=5)+
  geom_point(aes(x=subcaste, y=e2.mean),size=8) + 
  scale_color_manual(values=caste.colors) +
  scale_y_continuous(breaks=seq(0,0.5,0.05)) +
  theme.gg 
dev.off()

# Diversity by sex X species #
ic.alpha$spe<-ifelse(ic.alpha$colony=="mouse","mouse","nmr")
ic.alpha$sex.spe<-interaction(ic.alpha$spe,ic.alpha$sex)
ic.alpha$sex.spe <- factor(ic.alpha$sex.spe,
                          levels = c("nmr.female","nmr.male","mouse.female","mouse.male"),ordered = TRUE)
mean.alpha.sex.spe <- ic.alpha %>% group_by(sex.spe) %>% summarise_all(funs(mean))

mean.alpha.sex.spe<-as.data.frame(mean.alpha.sex.spe[,c(1,17:20)])
names(mean.alpha.sex.spe)<-c("sex.spe","obs.mean","shan.mean","inv.mean","e2.mean")

ic.alpha.sum<-merge(ic.alpha,mean.alpha.sex.spe,by="sex.spe",all=T)


pdf(file="~Manuscript/Figures/sex_invsimp.pdf",
    width=10,height=6,bg = "transparent")
ggplot(data=ic.alpha.sum, aes(x=sex.spe, y=InvSimpson, color = sex.spe)) +
  geom_jitter(alpha=.5,width=.3,size=5)+
  geom_point(aes(x=sex.spe, y=inv.mean),size=8) +
  scale_color_manual(values=c("#e34a33","#fdbb84","#2b8cbe","#a6bddb")) +
  scale_y_continuous(breaks=seq(0,100,10)) +
  theme.gg 
dev.off()


pdf(file="~Manuscript/Figures/sex_obs.pdf",
    width=10,height=6,bg = "transparent")
ggplot(data=ic.alpha, aes(x=sex.spe, y=Observed)) +
  geom_jitter(alpha=.5,width=.3,col="#e31a1c",size=2)+geom_boxplot(outlier.shape = NA,fill="#fb9a99") + scale_y_continuous(breaks=seq(0,500,25)) +
  theme.gg 
dev.off()

pdf(file="~Manuscript/Figures/sex_e2.pdf",
    width=10,height=6,bg = "transparent")
ggplot(data=ic.alpha, aes(x=sex.spe, y=E2)) +
  geom_jitter(alpha=.5,width=.3,col="#e31a1c",size=2)+geom_boxplot(outlier.shape = NA,fill="#fb9a99") + scale_y_continuous(breaks=seq(0,0.5,0.05)) +
  theme.gg 
dev.off()

#### Paired experiment ####
p.alpha$ind.id<-interaction(p.alpha$colony,p.alpha$sex)
pd <- position_dodge(0.3)

pdf(file="~Manuscript/Figures/paired.obs.pdf",
    width=10,height=6,bg = "transparent")
ggplot(data=p.alpha,aes(x=subcaste,y=Observed,group=ind.id,shape=sex,color=colony))+
  geom_line(size=2,position=pd,alpha=.5)+
  geom_point(aes(fill=colony,shape=sex),size=8,alpha=1,colour="black",position=pd) +
  scale_shape_manual(values=c(21, 22)) +
  scale_colour_manual(values=pair.colors) + 
  scale_fill_manual(values=pair.colors) + 
  scale_y_continuous(breaks=seq(0,400,25)) + theme.gg.leg
dev.off()

pdf(file="~Manuscript/Figures/paired.inv.pdf",
    width=10,height=6,bg = "transparent")
ggplot(data=p.alpha,aes(x=subcaste,y=InvSimpson,group=ind.id,shape=sex,color=colony))+
  geom_line(size=2,alpha=.5,position=pd)+
  geom_point(aes(fill=colony,shape=sex),size=8,alpha=0.9,colour="black",position=pd) +
  scale_shape_manual(values=c(21, 22)) +
  scale_colour_manual(values=pair.colors) + 
  scale_fill_manual(values=pair.colors) + 
  scale_y_continuous(breaks=seq(0,60,5)) + theme.gg.leg
dev.off()

pdf(file="~Manuscript/Figures/paired.e2.pdf",
    width=10,height=6,bg = "transparent")
ggplot(data=p.alpha,aes(x=subcaste,y=E2,group=ind.id,shape=sex,color=colony))+
  geom_line(size=1,position=pd)+
  geom_point(aes(fill=colony,shape=sex),size=2.5,colour="black",position=pd) +
  scale_shape_manual(values=c(21, 22)) +
  scale_colour_manual(values=pair.colors) + 
  scale_fill_manual(values=pair.colors) + 
  scale_y_continuous(breaks=seq(0,0.2,0.025)) + theme.gg.leg
dev.off()

# difference in diversity across timepoints #
inv.diff<-as.data.frame(c(t123.split$t1.inv.diff,t123.split$t2.inv.diff,t123.split$t3.inv.diff))
inv.diff$time<-c(rep("T1",10),rep("T2",10),rep("T3",10))
inv.diff$pair<-rep(c("pair1","pair10","pair2","pair3","pair4","pair5","pair6","pair7","pair8","pair9"),3)
names(inv.diff)<-c("diff","time","pair")

pdf(file="~Manuscript/Figures/paired.div.diff.boxplot.pdf",
    width=8,height=6,bg = "transparent")
ggplot(data=inv.diff, aes(x=time, y=abs(diff))) +
  geom_boxplot(outlier.color = "transparent", color="black",fill="grey") +
  geom_point(position=position_jitterdodge(jitter.width=0.5, dodge.width = 0), 
             pch=21, size = 10, aes(fill=pair,alpha=0.5)) +
  scale_y_continuous(breaks=seq(0,35,5)) +
  scale_fill_manual(values=pair.colors) +
  theme.gg.leg
dev.off()

##### 3) Beta diversity analyses #####
# Standard thresholding: 5 sample occurence x 25 reads (throw out "non-reproducible" OTUs) #
ps5<-subset_samples(ps4, experiment != "control" ) # remove  controls
threshold<-kOverA(5,A=25) # set threshold values (require k samples with A reads)
ps6<-filter_taxa(ps5,threshold,TRUE)
ntaxa(ps6) 
sum(taxa_sums(ps6))/sum(taxa_sums(ps5)) # common set of 553 ASVs represents 98% of all observations

# use either ps6 object, depending on the analysis #
ps6.ic<-subset_samples(ps6, experiment == "IC")
ps6.ic.nm<-subset_samples(ps6.ic, subcaste != "mouse")
ps6.p<-subset_samples(ps6, experiment == "P")
ps6.ic.2<-subset_samples(ps6.ic.nm, subcaste!="breeding_male" & subcaste!="queen")
ps6.mouse<-subset_samples(ps6, subcaste == "mouse")
ps6.nm<-subset_samples(ps6, subcaste != "mouse")

ps6.ic<-prune_taxa(taxa_sums(ps6.ic)>0,ps6.ic)
ps6.ic.nm<-prune_taxa(taxa_sums(ps6.ic.nm)>0,ps6.ic.nm)
ps6.p<-prune_taxa(taxa_sums(ps6.p)>0,ps6.p)
ps6.ic.2<-prune_taxa(taxa_sums(ps6.ic.2)>0,ps6.ic.2)
ps6.mouse<-prune_taxa(taxa_sums(ps6.mouse)>0,ps6.mouse)
ps6.nm<-prune_taxa(taxa_sums(ps6.nm)>0,ps6.nm)

## first change counts into relative abundance ##
ps6.ic.ra = transform_sample_counts(ps6.ic, rel.abund)
ps6.ic.nm.ra = transform_sample_counts(ps6.ic.nm, rel.abund)
ps6.p.ra = transform_sample_counts(ps6.p, rel.abund)
ps6.ic.2.ra = transform_sample_counts(ps6.ic.2, rel.abund)
ps6.mouse.ra = transform_sample_counts(ps6.mouse, rel.abund)
ps6.nm.ra = transform_sample_counts(ps6.nm, rel.abund)

## calculate dissimilarity metrics ##
out.wunifrac.ps6.ic <- phyloseq::ordinate(ps6.ic.ra, method = "MDS", distance = "wunifrac")
out.uunifrac.ps6.ic <- ordinate(ps6.ic.ra, method = "MDS", distance = "unifrac")
out.bray.ps6.ic <- phyloseq::ordinate(ps6.ic.ra, method = "MDS", distance = "bray")

out.wunifrac.ps6.ic.nm <- phyloseq::ordinate(ps6.ic.nm.ra, method = "MDS", distance = "wunifrac")
out.uunifrac.ps6.ic.nm <- ordinate(ps6.ic.nm.ra, method = "MDS", distance = "unifrac")
out.bray.ps6.ic.nm <- phyloseq::ordinate(ps6.ic.nm.ra, method = "MDS", distance = "bray")

out.wunifrac.ps6.p <- phyloseq::ordinate(ps6.p.ra, method = "MDS", distance = "wunifrac")
out.uunifrac.ps6.p <- ordinate(ps6.p.ra, method = "MDS", distance = "unifrac")
out.bray.ps6.p <- phyloseq::ordinate(ps6.p.ra, method = "MDS", distance = "bray")

out.wunifrac.ps6.ic.2 <- phyloseq::ordinate(ps6.ic.2.ra, method = "MDS", distance = "wunifrac")
out.uunifrac.ps6.ic.2 <- ordinate(ps6.ic.2.ra, method = "MDS", distance = "unifrac")
out.bray.ps6.ic.2 <- phyloseq::ordinate(ps6.ic.2.ra, method = "MDS", distance = "bray")

#### In colony experiment ####
## PERMANOVA ##
# Question 1) Do colonies, social groups, and sexes vary in diversity? #
# Full dataset #
md<-data.frame(sample_data(ps6.ic.nm.ra))
dist.wu.ic.nm <- phyloseq::distance(ps6.ic.nm.ra, method="wunifrac")
adonis2(dist.wu.ic.nm ~ subcaste+colony+rank+sex+age+weight+UsableReads+samp_weight, data = md,by="margin")

dist.uu.ic.nm <- phyloseq::distance(ps6.ic.nm.ra, method="uunifrac")
adonis2(dist.uu.ic.nm ~ subcaste+colony+sex+rank+age+weight+UsableReads+samp_weight, data = md,by="margin")

dist.bray.ic.nm <- phyloseq::distance(ps6.ic.nm.ra, method="bray")
adonis2(dist.bray.ic.nm ~ subcaste+colony+sex+rank+age+weight+UsableReads+samp_weight, data = md,by="margin")

# Question 2) Do colony, subcaste, or sex interact to affect diversity? #
# need to remove Queen and Breeding Males #
md.2<-data.frame(sample_data(ps6.ic.2.ra))
dist.wu.ic.2 <- phyloseq::distance(ps6.ic.2.ra, method="wunifrac")
adonis2(dist.wu.ic.2 ~ subcaste+colony+sex+subcaste:colony+colony:sex+subcaste:sex+rank+age+weight+UsableReads+samp_weight, data = md.2,by="margin")

dist.uu.ic.2 <- phyloseq::distance(ps6.ic.2.ra, method="uunifrac")
adonis2(dist.uu.ic.2 ~ subcaste+colony+sex+subcaste:colony+colony:sex+subcaste:sex+rank+age+weight+UsableReads+samp_weight, data = md.2,by="margin")

dist.bray.ic.2 <- phyloseq::distance(ps6.ic.2.ra, method="bray")
adonis2(dist.bray.ic.2 ~ subcaste+colony+sex+subcaste:colony+colony:sex+subcaste:sex+rank+age+weight+UsableReads+samp_weight, data = md.2,by="margin")

# Question 3) Do species/sex vary in composition?
md.ps.6<-data.frame(sample_data(ps6.ic.ra))
dist.wu.ic <- phyloseq::distance(ps6.ic.ra, method="bray")
adonis2(dist.wu.ic ~ spe*sex+UsableReads+samp_weight, data = md.ps.6,by="margin")


# Are breeders more similar to one another than queen versus subs? #
dist.wu.ps6.ic.nm<-phyloseq::distance(ps6.ic.nm.ra, method="wunifrac")
dist.wu.ps6.ic.nm.1<-as.matrix(dist.wu.ps6.ic.nm)
dist.ps6.ic<-cbind(ic.alpha.nm[,c(3,c(6:8))],dist.wu.ps6.ic.nm.1)

# separate colonies #
eliz.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Elizabeth",] # no queen
fent.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Fenty",]
ich.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Ichabod",]
lucy.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Lucy",] # no breeding male
mac.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Macbeth",]
xena.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Xena",]

# isolate distances relative to queen
fent.dist.q<-fent.dist[,c(1:4,75)]
ich.dist.q<-ich.dist[,c(1:4,12)]
mac.dist.q<-mac.dist[,c(1:4,52)]
xena.dist.q<-xena.dist[,c(1:4,21)]

# isolate distances relative to breeding male
fent.dist.m<-fent.dist[,c(1:4,30)]
ich.dist.m<-ich.dist[,c(1:4,6)]
mac.dist.m<-mac.dist[,c(1:4,17)]
xena.dist.m<-xena.dist[,c(1:4,8)]

# separate distance between breeders from distance between queen and subs #
fent.breed.dist<-fent.dist.q[fent.dist.q$subcaste=="breeding_male",5]
fent.qsub.dist<-fent.dist.q[fent.dist.q$subcaste !="breeding_male"& fent.dist.q$subcaste !="queen",5]
fent.msub.dist<-fent.dist.m[fent.dist.m$subcaste !="breeding_male"& fent.dist.m$subcaste !="queen",5]

fenty.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Fenty",] 
fenty.dist.nobreeders<-fenty.dist[fenty.dist$subcaste!="breeding_male" &fenty.dist$subcaste!="queen",]
fenty.dist.nobreeders<-fenty.dist.nobreeders[,-c(1:4)]
fenty.names<-rownames(fenty.dist.nobreeders)
fenty.dist.intra.nobreeders<-fenty.dist.nobreeders[,c(fenty.names)]
fenty.dist.intra.nobreeders<-as.matrix(fenty.dist.intra.nobreeders)
fenty.dist.intra.nobreeders<-upperTriangle(fenty.dist.intra.nobreeders)
mean(fenty.dist.intra.nobreeders)

mean(fent.qsub.dist)
hist(fent.qsub.dist)
mean(fent.msub.dist)
hist(fent.msub.dist)

z<-(fent.breed.dist-mean(fent.qsub.dist))/sd(fent.qsub.dist) # 
1-pnorm(z) # 0.98

z<-(fent.breed.dist-mean(fent.msub.dist))/sd(fent.msub.dist) # 
1-pnorm(z) # 0.88

z<-(mean(fent.qsub.dist)-mean(fenty.dist.intra.nobreeders))/sd(fenty.dist.intra.nobreeders) # 
1-pnorm(z) # 0.056

z<-(mean(fent.msub.dist)-mean(fenty.dist.intra.nobreeders))/sd(fenty.dist.intra.nobreeders) # 
1-pnorm(z) # 0.26

z<-(fent.breed.dist-mean(fenty.dist.intra.nobreeders))/sd(fenty.dist.intra.nobreeders) # 
1-pnorm(z) # 0.58

ich.breed.dist<-ich.dist.q[ich.dist.q$subcaste=="breeding_male",5]
ich.qsub.dist<-ich.dist.q[ich.dist.q$subcaste !="breeding_male"& ich.dist.q$subcaste !="queen",5]
ich.msub.dist<-ich.dist.m[ich.dist.m$subcaste !="breeding_male"& ich.dist.m$subcaste !="queen",5]

ichy.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Ichabod",] 
ichy.dist.nobreeders<-ichy.dist[ichy.dist$subcaste!="breeding_male" &ichy.dist$subcaste!="queen",]
ichy.dist.nobreeders<-ichy.dist.nobreeders[,-c(1:4)]
ichy.names<-rownames(ichy.dist.nobreeders)
ichy.dist.intra.nobreeders<-ichy.dist.nobreeders[,c(ichy.names)]
ichy.dist.intra.nobreeders<-as.matrix(ichy.dist.intra.nobreeders)
ichy.dist.intra.nobreeders<-upperTriangle(ichy.dist.intra.nobreeders)
mean(ichy.dist.intra.nobreeders)

mean(ich.qsub.dist)
hist(ich.qsub.dist)
mean(ich.msub.dist)
hist(ich.msub.dist)

z<-(ich.breed.dist-mean(ich.qsub.dist))/sd(ich.qsub.dist) # 
1-pnorm(z) # 0.24

z<-(ich.breed.dist-mean(ich.msub.dist))/sd(ich.msub.dist) # 
1-pnorm(z) # 0.02

z<-(mean(ich.qsub.dist)-mean(ichy.dist.intra.nobreeders))/sd(ichy.dist.intra.nobreeders) # 
1-pnorm(z) # 0.20

z<-(mean(ich.msub.dist)-mean(ichy.dist.intra.nobreeders))/sd(ichy.dist.intra.nobreeders) # 
1-pnorm(z) # 0.49

z<-(ich.breed.dist-mean(ichy.dist.intra.nobreeders))/sd(ichy.dist.intra.nobreeders) # 
1-pnorm(z) # 0.05


mac.breed.dist<-mac.dist.q[mac.dist.q$subcaste=="breeding_male",5]
mac.qsub.dist<-mac.dist.q[mac.dist.q$subcaste !="breeding_male"& mac.dist.q$subcaste !="queen",5]
mac.msub.dist<-mac.dist.m[mac.dist.m$subcaste !="breeding_male"& mac.dist.m$subcaste !="queen",5]

macy.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Macbeth",] 
macy.dist.nobreeders<-macy.dist[macy.dist$subcaste!="breeding_male" &macy.dist$subcaste!="queen",]
macy.dist.nobreeders<-macy.dist.nobreeders[,-c(1:4)]
macy.names<-rownames(macy.dist.nobreeders)
macy.dist.intra.nobreeders<-macy.dist.nobreeders[,c(macy.names)]
macy.dist.intra.nobreeders<-as.matrix(macy.dist.intra.nobreeders)
macy.dist.intra.nobreeders<-upperTriangle(macy.dist.intra.nobreeders)
mean(macy.dist.intra.nobreeders)

mean(mac.qsub.dist)
hist(mac.qsub.dist)
mean(mac.msub.dist)
hist(mac.msub.dist)

z<-(mac.breed.dist-mean(mac.qsub.dist))/sd(mac.qsub.dist) # 
1-pnorm(z) # 0.33

z<-(mac.breed.dist-mean(mac.msub.dist))/sd(mac.msub.dist) # 
1-pnorm(z) # 0.34

z<-(mean(mac.qsub.dist)-mean(macy.dist.intra.nobreeders))/sd(macy.dist.intra.nobreeders) # 
1-pnorm(z) # 0.37

z<-(mean(mac.msub.dist)-mean(macy.dist.intra.nobreeders))/sd(macy.dist.intra.nobreeders) # 
1-pnorm(z) # 0.44

z<-(mac.breed.dist-mean(macy.dist.intra.nobreeders))/sd(macy.dist.intra.nobreeders) # 
1-pnorm(z) # 0.28


xena.breed.dist<-xena.dist.q[xena.dist.q$subcaste=="breeding_male",5]
xena.qsub.dist<-xena.dist.q[xena.dist.q$subcaste !="breeding_male"& xena.dist.q$subcaste !="queen",5]
xena.msub.dist<-xena.dist.m[xena.dist.m$subcaste !="breeding_male"& xena.dist.m$subcaste !="queen",5]

xenay.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Xena",] 
xenay.dist.nobreeders<-xenay.dist[xenay.dist$subcaste!="breeding_male" &xenay.dist$subcaste!="queen",]
xenay.dist.nobreeders<-xenay.dist.nobreeders[,-c(1:4)]
xenay.names<-rownames(xenay.dist.nobreeders)
xenay.dist.intra.nobreeders<-xenay.dist.nobreeders[,c(xenay.names)]
xenay.dist.intra.nobreeders<-as.matrix(xenay.dist.intra.nobreeders)
xenay.dist.intra.nobreeders<-upperTriangle(xenay.dist.intra.nobreeders)
mean(xenay.dist.intra.nobreeders)

mean(xena.qsub.dist)
hist(xena.qsub.dist)
mean(xena.msub.dist)
hist(xena.msub.dist)

z<-(xena.breed.dist-mean(xena.qsub.dist))/sd(xena.qsub.dist) # 
1-pnorm(z) # 0.14

z<-(xena.breed.dist-mean(xena.msub.dist))/sd(xena.msub.dist) # 
1-pnorm(z) # 0.98

z<-(mean(xena.qsub.dist)-mean(xenay.dist.intra.nobreeders))/sd(xenay.dist.intra.nobreeders) # 
1-pnorm(z) # 0.77

z<-(mean(xena.msub.dist)-mean(xenay.dist.intra.nobreeders))/sd(xenay.dist.intra.nobreeders) # 
1-pnorm(z) # 0.06

z<-(xena.breed.dist-mean(xenay.dist.intra.nobreeders))/sd(xenay.dist.intra.nobreeders) # 
1-pnorm(z) # 0.37

mean.breed.dist<-mean(c(fent.breed.dist,ich.breed.dist,mac.breed.dist,xena.breed.dist))
mean.qsub.dist<-mean(c(fent.qsub.dist,ich.qsub.dist,mac.qsub.dist,xena.qsub.dist))


##### Calculating intra and inter- colony/subcaste WU distances ####
dist.wu.ps6.ic.nm<-phyloseq::distance(ps6.ic.nm.ra, method="wunifrac")
dist.wu.ps6.ic.nm.1<-as.matrix(dist.wu.ps6.ic.nm)
dist.ps6.ic<-cbind(ic.alpha.nm[,c(3,c(6:8))],dist.wu.ps6.ic.nm.1)

# separate colonies #
elizabeth.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Elizabeth",] # no queen
elizabeth.dist<-elizabeth.dist[,-c(1:4)]
elizabeth.names<-rownames(elizabeth.dist)
elizabeth.dist.intra<-elizabeth.dist[,c(rownames(elizabeth.dist))]
elizabeth.dist.intra<-as.matrix(elizabeth.dist.intra)
Elizabeth.intra<-upperTriangle(elizabeth.dist.intra)
Elizabeth.inter<-as.vector(as.matrix(elizabeth.dist[,-which(names(elizabeth.dist) %in% rownames(elizabeth.dist))]))
mean(Elizabeth.intra)
mean(Elizabeth.inter)
wilcox.test(Elizabeth.intra,Elizabeth.inter)

Ichabod.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Ichabod",] # no queen
Ichabod.dist<-Ichabod.dist[,-c(1:4)]
Ichabod.names<-rownames(Ichabod.dist)
Ichabod.dist.intra<-Ichabod.dist[,c(rownames(Ichabod.dist))]
Ichabod.dist.intra<-as.matrix(Ichabod.dist.intra)
Ichabod.intra<-upperTriangle(Ichabod.dist.intra)
Ichabod.inter<-as.vector(as.matrix(Ichabod.dist[,-which(names(Ichabod.dist) %in% rownames(Ichabod.dist))]))
mean(Ichabod.intra)
mean(Ichabod.inter)
wilcox.test(Ichabod.inter,Ichabod.intra)

Fenty.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Fenty",] # no queen
Fenty.dist<-Fenty.dist[,-c(1:4)]
Fenty.names<-rownames(Fenty.dist)
Fenty.dist.intra<-Fenty.dist[,c(rownames(Fenty.dist))]
Fenty.dist.intra<-as.matrix(Fenty.dist.intra)
Fenty.intra<-upperTriangle(Fenty.dist.intra)
Fenty.inter<-as.vector(as.matrix(Fenty.dist[,-which(names(Fenty.dist) %in% rownames(Fenty.dist))]))
mean(Fenty.intra)
mean(Fenty.inter)
wilcox.test(Fenty.inter,Fenty.intra)

Lucy.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Lucy",] # no queen
Lucy.dist<-Lucy.dist[,-c(1:4)]
Lucy.names<-rownames(Lucy.dist)
Lucy.dist.intra<-Lucy.dist[,c(rownames(Lucy.dist))]
Lucy.dist.intra<-as.matrix(Lucy.dist.intra)
Lucy.intra<-upperTriangle(Lucy.dist.intra)
Lucy.inter<-as.vector(as.matrix(Lucy.dist[,-which(names(Lucy.dist) %in% rownames(Lucy.dist))]))
mean(Lucy.intra)
mean(Lucy.inter)
wilcox.test(Lucy.inter,Lucy.intra)

Xena.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Xena",] # no queen
Xena.dist<-Xena.dist[,-c(1:4)]
Xena.names<-rownames(Xena.dist)
Xena.dist.intra<-Xena.dist[,c(rownames(Xena.dist))]
Xena.dist.intra<-as.matrix(Xena.dist.intra)
Xena.intra<-upperTriangle(Xena.dist.intra)
Xena.inter<-as.vector(as.matrix(Xena.dist[,-which(names(Xena.dist) %in% rownames(Xena.dist))]))
mean(Xena.intra)
mean(Xena.inter)
wilcox.test(Xena.inter,Xena.intra)

Macbeth.dist<-dist.ps6.ic[dist.ps6.ic$colony=="Macbeth",] # no queen
Macbeth.dist<-Macbeth.dist[,-c(1:4)]
Macbeth.names<-rownames(Macbeth.dist)
Macbeth.dist.intra<-Macbeth.dist[,c(rownames(Macbeth.dist))]
Macbeth.dist.intra<-as.matrix(Macbeth.dist.intra)
Macbeth.intra<-upperTriangle(Macbeth.dist.intra)
Macbeth.inter<-as.vector(as.matrix(Macbeth.dist[,-which(names(Macbeth.dist) %in% rownames(Macbeth.dist))]))
mean(Macbeth.intra)
mean(Macbeth.inter)
wilcox.test(Macbeth.inter,Macbeth.intra)

colony.comb.dist<-as.data.frame(c(rep("xena",length(Xena.intra)+length(Xena.inter)),
                                  rep("lucy",length(Lucy.intra)+length(Lucy.inter)),
                                  rep("elizabeth",length(Elizabeth.intra)+length(Elizabeth.inter)),
                                  rep("macbeth",length(Macbeth.intra)+length(Macbeth.inter)),
                                  rep("fenty",length(Fenty.intra)+length(Fenty.inter)),
                                  rep("ichabod",length(Ichabod.intra)+length(Ichabod.inter))))

colony.comb.dist$type<-c(rep("in",length(Xena.intra)),rep("out",length(Xena.inter)),
                         rep("in",length(Lucy.intra)),rep("out",length(Lucy.inter)),
                         rep("in",length(Elizabeth.intra)),rep("out",length(Elizabeth.inter)),
                         rep("in",length(Macbeth.intra)),rep("out",length(Macbeth.inter)),
                         rep("in",length(Fenty.intra)),rep("out",length(Fenty.inter)),
                         rep("in",length(Ichabod.intra)),rep("out",length(Ichabod.inter)))

colony.comb.dist$dist<-c(Xena.intra,Xena.inter,Lucy.intra,Lucy.inter,Elizabeth.intra,Elizabeth.inter,
                    Macbeth.intra,Macbeth.inter,Fenty.intra,Fenty.inter,Ichabod.intra,Ichabod.inter)

colnames(colony.comb.dist)<-c("colony","type","dist")

colony.comb.dist$col.type<-interaction(colony.comb.dist$colony,colony.comb.dist$type)

mean.col.dist <- colony.comb.dist %>% group_by(col.type) %>% summarise_all(funs(mean))
                                               
mean.col.dist<-as.data.frame(mean.col.dist[,c(1,4)])

names(mean.col.dist)<-c("col.type","mean.dist")
colony.comb.dist<-merge(colony.comb.dist,mean.col.dist,by="col.type",all=T)


pdf(file="~Manuscript/Figures/colony_dist.pdf",
    width=10,height=5,bg = "transparent")
ggplot(colony.comb.dist, aes(x=colony, y=dist, fill=type)) +
  geom_boxplot(outlier.shape=NA) +
  scale_fill_manual(values=c("#f0f0f0", "#f0f0f0")) +
  coord_cartesian(ylim = c(0.07,0.56)) +
  scale_x_discrete(limits=c("xena", "lucy", "elizabeth", "macbeth", "fenty", "ichabod")) +
  theme.gg.blankx
dev.off()


# separate subcastes #
worker.dist<-dist.ps6.ic[dist.ps6.ic$subcaste=="worker",] # no queen
worker.dist<-worker.dist[,-c(1:4)]
worker.names<-rownames(worker.dist)
worker.dist.intra<-worker.dist[,c(rownames(worker.dist))]
worker.dist.intra<-as.matrix(worker.dist.intra)
worker.intra<-upperTriangle(worker.dist.intra)
worker.inter<-as.vector(as.matrix(worker.dist[,-which(names(worker.dist) %in% rownames(worker.dist))]))
mean(worker.intra)
mean(worker.inter)
wilcox.test(worker.inter,worker.intra)

soldier.dist<-dist.ps6.ic[dist.ps6.ic$subcaste=="soldier",] # no queen
soldier.dist<-soldier.dist[,-c(1:4)]
soldier.names<-rownames(soldier.dist)
soldier.dist.intra<-soldier.dist[,c(rownames(soldier.dist))]
soldier.dist.intra<-as.matrix(soldier.dist.intra)
soldier.intra<-upperTriangle(soldier.dist.intra)
soldier.inter<-as.vector(as.matrix(soldier.dist[,-which(names(soldier.dist) %in% rownames(soldier.dist))]))
mean(soldier.intra)
mean(soldier.inter)
wilcox.test(soldier.inter,soldier.intra)

disperser.dist<-dist.ps6.ic[dist.ps6.ic$subcaste=="disperser",] # no queen
disperser.dist<-disperser.dist[,-c(1:4)]
disperser.names<-rownames(disperser.dist)
disperser.dist.intra<-disperser.dist[,c(rownames(disperser.dist))]
disperser.dist.intra<-as.matrix(disperser.dist.intra)
disperser.intra<-upperTriangle(disperser.dist.intra)
disperser.inter<-as.vector(as.matrix(disperser.dist[,-which(names(disperser.dist) %in% rownames(disperser.dist))]))
mean(disperser.intra)
mean(disperser.inter)
wilcox.test(disperser.inter,disperser.intra)

breeding_male.dist<-dist.ps6.ic[dist.ps6.ic$subcaste=="breeding_male",] # no queen
breeding_male.dist<-breeding_male.dist[,-c(1:4)]
breeding_male.names<-rownames(breeding_male.dist)
breeding_male.dist.intra<-breeding_male.dist[,c(rownames(breeding_male.dist))]
breeding_male.dist.intra<-as.matrix(breeding_male.dist.intra)
breeding_male.intra<-upperTriangle(breeding_male.dist.intra)
breeding_male.inter<-as.vector(as.matrix(breeding_male.dist[,-which(names(breeding_male.dist) %in% rownames(breeding_male.dist))]))
mean(breeding_male.intra)
mean(breeding_male.inter)
wilcox.test(breeding_male.inter,breeding_male.intra)

queen.dist<-dist.ps6.ic[dist.ps6.ic$subcaste=="queen",] # no queen
queen.dist<-queen.dist[,-c(1:4)]
queen.names<-rownames(queen.dist)
queen.dist.intra<-queen.dist[,c(rownames(queen.dist))]
queen.dist.intra<-as.matrix(queen.dist.intra)
queen.intra<-upperTriangle(queen.dist.intra)
queen.inter<-as.vector(as.matrix(queen.dist[,-which(names(queen.dist) %in% rownames(queen.dist))]))
mean(queen.intra)
mean(queen.inter)
wilcox.test(queen.inter,queen.intra)

subcaste.comb.dist<-as.data.frame(c(rep("worker",length(worker.intra)+length(worker.inter)),
                                  rep("soldier",length(soldier.intra)+length(soldier.inter)),
                                  rep("disperser",length(disperser.intra)+length(disperser.inter)),
                                  rep("breeding_male",length(breeding_male.intra)+length(breeding_male.inter)),
                                  rep("queen",length(queen.intra)+length(queen.inter))))

subcaste.comb.dist$type<-c(rep("in",length(worker.intra)),rep("out",length(worker.inter)),
                         rep("in",length(soldier.intra)),rep("out",length(soldier.inter)),
                         rep("in",length(disperser.intra)),rep("out",length(disperser.inter)),
                         rep("in",length(breeding_male.intra)),rep("out",length(breeding_male.inter)),
                         rep("in",length(queen.intra)),rep("out",length(queen.inter)))

subcaste.comb.dist$dist<-c(worker.intra,worker.inter,soldier.intra,soldier.inter,disperser.intra,disperser.inter,
                         breeding_male.intra,breeding_male.inter,queen.intra,queen.inter)

colnames(subcaste.comb.dist)<-c("subcaste","type","dist")

subcaste.comb.dist$col.type<-interaction(subcaste.comb.dist$subcaste,subcaste.comb.dist$type)

mean.col.dist <- subcaste.comb.dist %>% group_by(col.type) %>% summarise_all(funs(mean))

mean.col.dist<-as.data.frame(mean.col.dist[,c(1,4)])

names(mean.col.dist)<-c("col.type","mean.dist")
subcaste.comb.dist<-merge(subcaste.comb.dist,mean.col.dist,by="col.type",all=T)


pdf(file="~Manuscript/Figures/subcaste_dist.pdf",
    width=10,height=5,bg = "transparent")
ggplot(subcaste.comb.dist, aes(x=subcaste, y=dist, fill=type)) +
  geom_boxplot(outlier.shape=NA) +
  scale_fill_manual(values=c("#f0f0f0", "#f0f0f0")) +
  coord_cartesian(ylim = c(0.07,0.56)) +
  scale_x_discrete(limits=c("worker", "soldier", "disperser", "breeding_male", "queen")) +
  theme.gg.blankx
dev.off()


#### Paired experiment ####
dist.wu.pair <- phyloseq::distance(ps6.p.ra, method="wunifrac")
dist.uu.pair <- phyloseq::distance(ps6.p.ra, method="uunifrac")
dist.bc.pair <- phyloseq::distance(ps6.p.ra, method="bray")
md.pair<-data.frame(sample_data(ps6.p.ra))
adonis2(dist.wu.pair ~ colony+subcaste+sex+log(UsableReads)+samp_weight+colony:subcaste+sex:subcaste, data = md.pair)
adonis2(dist.uu.pair ~ colony+subcaste+sex+log(UsableReads)+samp_weight+colony:subcaste+sex:subcaste, data = md.pair)
adonis2(dist.bc.pair ~ colony+subcaste+sex+log(UsableReads)+samp_weight+colony:subcaste+sex:subcaste, data = md.pair)

# strong effect of time point but not pair or time:pair

# Is the simmilarity between a pair of individuals increasing over time? #

dist.wu.pair <- phyloseq::distance(ps6.p.ra, method="wunifrac")
dist.wu.pair.1<-as.matrix(dist.wu.pair)
dist.uu.pair.1<-as.matrix(dist.uu.pair)
dist.bc.pair.1<-as.matrix(dist.bc.pair)
dist.pair<-cbind(p.alpha[,c(3,6,14)],dist.bc.pair.1)

dist.T1<-dist.pair[dist.pair$subcaste=="T1",c(rownames(dist.pair[dist.pair$subcaste=="T1",]))]
dist.T1<-cbind(p.alpha[p.alpha$subcaste=="T1",c(3,6,14)],dist.T1)
dist.T1 <- dist.T1[order(dist.T1$ind.id),] 
dist.T1.all.pair<-c(dist.T1[1,7],dist.T1[2,4],dist.T1[3,19],dist.T1[4,16],dist.T1[5,21],
                    dist.T1[6,17],dist.T1[7,9],dist.T1[8,13],dist.T1[9,18],dist.T1[10,11])

dist.T2<-dist.pair[dist.pair$subcaste=="T2",c(rownames(dist.pair[dist.pair$subcaste=="T2",]))]
dist.T2<-cbind(p.alpha[p.alpha$subcaste=="T2",c(3,6,14)],dist.T2)
dist.T2 <- dist.T2[order(dist.T2$ind.id),] 
dist.T2.all.pair<-c(dist.T2[1,10],dist.T2[2,21],dist.T2[3,11],dist.T2[4,7],dist.T2[5,16],
                    dist.T2[6,8],dist.T2[7,19],dist.T2[8,14],0,0)

dist.T3<-dist.pair[dist.pair$subcaste=="T3",c(rownames(dist.pair[dist.pair$subcaste=="T3",]))]
dist.T3<-cbind(p.alpha[p.alpha$subcaste=="T3",c(3,6,14)],dist.T3)
dist.T3 <- dist.T3[order(dist.T3$ind.id),] 
dist.T3.all.pair<-c(dist.T3[1,16],dist.T3[2,6],dist.T3[3,20],dist.T3[4,11],dist.T3[5,12],
                    dist.T3[6,8],dist.T3[7,9],dist.T3[8,14],dist.T3[9,15],dist.T3[10,17])


dist.123<-as.data.frame(cbind(dist.T1.all.pair,dist.T2.all.pair,dist.T3.all.pair))
dist.123[dist.123 == 0] <- NA
colnames(dist.123)<-c("T1","T2","T3")
dist.123$pair<-dist.T1[1:10,1]
library(tidyr)
dist.123.long <- gather(dist.123, time, distance, T1:T3, factor_key=TRUE)

# are they sig. different?
t.test(dist.123$T1,dist.123$T2,paired=T,alternative="two.sided") # t = -1.77 df = 7 p = 0.94
t.test(dist.123$T1,dist.123$T3,paired=T,alternative="two.sided") # t = 0.54 df = 9 p = 0.30
t.test(dist.123$T2,dist.123$T3,paired=T,alternative="two.sided") # t = -2.89 df = 7 p = 0.01

pd <- position_dodge(0.1)

pdf(file="~Manuscript/Figures/paired.wunifrac.pdf",
    width=10,height=6,bg = "transparent")
ggplot(data=dist.123.long,aes(x=time,y=distance,group=pair,color=pair))+
  geom_line(size=2)+
  geom_point(aes(fill=pair),size=2.5,shape=21,color="black") +
  scale_colour_manual(values=pair.colors) + 
  scale_fill_manual(values=pair.colors) + 
  scale_y_continuous(breaks=seq(0,0.3,0.05)) + theme.gg.leg
dev.off()

pdf(file="~Manuscript/Figures/paired.wunifrac.boxplot.pdf",
    width=8,height=6,bg = "transparent")
ggplot(data=dist.123.long, aes(x=time, y=distance)) +
  geom_boxplot(outlier.color = "transparent", color="black",fill="grey") +
  geom_point(position=position_jitterdodge(jitter.width=2, dodge.width = 0), 
             pch=21, size = 10, aes(fill=pair,alpha=0.5)) +
  scale_y_continuous(breaks=seq(0,0.4,0.05)) +
  scale_fill_manual(values=pair.colors) +
  theme.gg.leg
dev.off()


#### 3.1) Beta Diversity Figures ####

# In Colony, mouse included #
pdf(file="~Manuscript/Figures/PCoA.wunifrac.IC.pdf",
    width=10,height=7,bg = "transparent")
plot_ordination(ps6.ic.ra, out.wunifrac.ps6.ic, type="samples", color="colony") +
  geom_point(aes(fill=colony),size=10, shape = 21, color="black") + 
  scale_fill_manual(values=colony.colors) +
  scale_x_continuous(breaks=seq(-0.4,0.5,0.1)) +
  scale_y_continuous(breaks=seq(-0.4,0.4,0.1)) +
  theme.gg
dev.off()

pdf(file="~Manuscript/Figures/PCoA.wunifrac.IC.sex.species.pdf",
    width=10,height=7,bg = "transparent")
plot_ordination(ps6.ic.ra, out.wunifrac.ps6.ic, type="samples", color="spe") +
  geom_point(aes(fill=spe,shape = sex),size=10, color="black") +
  scale_shape_manual(values=c(21,24)) +
  scale_fill_manual(values=c("#6a51a3","#fd8d3c")) +
  scale_x_continuous(breaks=seq(-0.4,0.5,0.1)) +
  scale_y_continuous(breaks=seq(-0.4,0.4,0.1)) +
  theme.gg.leg
dev.off()

# In Colony, mouse excluded #
pdf(file="~Manuscript/Figures/PCoA.wunifrac.IC.nm.pdf",
    width=10,height=7,bg = "transparent")
plot_ordination(ps6.ic.nm.ra, out.wunifrac.ps6.ic.nm, type="samples", color="colony") +
  geom_point(aes(fill=colony),size=10, shape = 21, color="black") + 
  scale_fill_manual(values=colony.colors) +
  scale_x_continuous(breaks=seq(-0.4,0.5,0.1)) +
  scale_y_continuous(breaks=seq(-0.4,0.4,0.1)) +
  theme.gg
dev.off()

pdf(file="~Manuscript/Figures/PCoA.wunifrac.IC.nm.sex.colony.pdf",
    width=10,height=7,bg = "transparent")
plot_ordination(ps6.ic.nm.ra, out.wunifrac.ps6.ic.nm, type="samples", color="colony", shape ="sex") +
  geom_point(aes(fill=colony),size=10, color="black") + 
  scale_fill_manual(values=colony.colors) +
  scale_shape_manual(values=c(21,24)) +
  scale_x_continuous(breaks=seq(-0.4,0.5,0.1)) +
  scale_y_continuous(breaks=seq(-0.4,0.4,0.1)) +
  theme.gg.leg
dev.off()

pdf(file="~Manuscript/Figures/PCoA.wunifrac.IC.nm.subcaste.pdf",
    width=10,height=7,bg = "transparent")
plot_ordination(ps6.ic.nm.ra, out.wunifrac.ps6.ic.nm, type="samples", color="subcaste") +
  geom_point(aes(fill=subcaste),size=10, shape = 21, color="black") + 
  scale_fill_manual(values=caste.colors) +
  scale_x_continuous(breaks=seq(-0.4,0.5,0.1)) +
  scale_y_continuous(breaks=seq(-0.4,0.4,0.1)) +
  theme.gg
dev.off()

# In Colony, breeders excluded #
pdf(file="~Manuscript/Figures/PCoA.wunifrac.IC.2.pdf",
    width=10,height=7,bg = "transparent")
plot_ordination(ps6.ic.2.ra, out.wunifrac.ps6.ic.2, type="samples", color="colony") +
  geom_point(aes(fill=colony),size=10, shape = 21, color="black") + 
  scale_fill_manual(values=colony.colors) +
  scale_x_continuous(breaks=seq(-0.4,0.5,0.1)) +
  scale_y_continuous(breaks=seq(-0.4,0.4,0.1)) +
  theme.gg.leg
dev.off()

pdf(file="~Manuscript/Figures/PCoA.wunifrac.IC.2.subcaste.pdf",
    width=10,height=7,bg = "transparent")
plot_ordination(ps6.ic.2.ra, out.wunifrac.ps6.ic.2, type="samples", color="subcaste") +
  geom_point(aes(fill=subcaste),size=10, shape = 21, color="black") + 
  scale_fill_manual(values=caste.colors) +
  scale_x_continuous(breaks=seq(-0.4,0.5,0.1)) +
  scale_y_continuous(breaks=seq(-0.4,0.4,0.1)) +
  theme.gg.leg
dev.off()


# Paired #

sample_data(ps6.p.ra)$timesex<-interaction(sample_data(ps6.p.ra)$subcaste,sample_data(ps6.p.ra)$sex)
sample_data(ps2)$UsableReads<-sample_sums(ps2)
pdf(file="~Manuscript/Figures/PCoA.wunifrac.p.pdf",
    width=10,height=7,bg = "transparent")
plot_ordination(ps6.p.ra, out.wunifrac.ps6.p, type="samples", color="colony", shape = "subcaste") +
  geom_point(aes(fill=colony,shape=subcaste,size=sex),color="black") + 
  scale_shape_manual(values=c(21,22,24)) +
  scale_fill_manual(values=pair.colors) +
  scale_color_manual(values=pair.colors) +
  scale_x_continuous(breaks=seq(-0.4,0.5,0.1)) +
  scale_y_continuous(breaks=seq(-0.4,0.4,0.1)) +
  scale_size_manual(values=c(10,5)) +
  theme.gg.leg
dev.off()

pdf(file="~Manuscript/Figures/PCoA.wunifrac.p.stroke.pdf",
    width=12,height=8,bg = "transparent")
plot_ordination(ps6.p.ra, out.wunifrac.ps6.p, type="samples") +
  geom_point(aes(fill=colony,shape=subcaste,color=sex),size=10,stroke=2) + 
  scale_shape_manual(values=c(21,22,24)) +
  scale_fill_manual(values=pair.colors) +
  scale_color_manual(values=c("#000000","#737373")) +
  scale_x_continuous(breaks=seq(-0.4,0.5,0.1)) +
  scale_y_continuous(breaks=seq(-0.4,0.4,0.1)) +
  theme.gg.leg
dev.off()


plot_ordination(ps6.p.ra, out.bray.ps6.p, type="samples") +
  geom_point(aes(color=colony),size=10,stroke=2) + 
  scale_x_continuous(breaks=seq(-0.4,0.5,0.1)) +
  scale_y_continuous(breaks=seq(-0.4,0.4,0.1)) +
  theme.gg.leg


#### 3.1.1) Relative abundance stacked barchart figure #####
ps6.ic.nm.ra.phy<-tax_glom(ps6.ic.nm.ra,taxrank="Phylum")
taxa_names(ps6.ic.nm.ra.phy)<-as.data.frame(tax_table(ps6.ic.nm.ra.phy)[,2])$Phylum   # update taxa names
relabund.phy<-cbind(as(sample_data(ps6.ic.nm.ra.phy),'data.frame'),as.data.frame(otu_table(ps6.ic.nm.ra.phy))) # data frame of phyla abundance and sample data

ps6.ic.ra.phy<-tax_glom(ps6.ic.ra,taxrank="Phylum")
taxa_names(ps6.ic.ra.phy)<-as.data.frame(tax_table(ps6.ic.ra.phy)[,2])$Phylum   # update taxa names
relabund.phy.m<-cbind(as(sample_data(ps6.ic.ra.phy),'data.frame'),as.data.frame(otu_table(ps6.ic.ra.phy))) # data frame of phyla abundance and sample data

ps6.ic.nm.ra.cla<-tax_glom(ps6.ic.nm.ra,taxrank="Class")
taxa_names(ps6.ic.nm.ra.cla)<-as.data.frame(tax_table(ps6.ic.nm.ra.cla)[,3])$Class   # update taxa names
relabund.cla<-cbind(as(sample_data(ps6.ic.nm.ra.cla),'data.frame'),as.data.frame(otu_table(ps6.ic.nm.ra.cla))) # data frame of phyla abundance and sample data

ps6.ic.nm.ra.ord<-tax_glom(ps6.ic.nm.ra,taxrank="Order")
taxa_names(ps6.ic.nm.ra.ord)<-as.data.frame(tax_table(ps6.ic.nm.ra.ord)[,4])$Order   # update taxa names
relabund.ord<-cbind(as(sample_data(ps6.ic.nm.ra.ord),'data.frame'),as.data.frame(otu_table(ps6.ic.nm.ra.ord))) # data frame of phyla abundance and sample data

ps6.ic.nm.ra.fam<-tax_glom(ps6.ic.nm.ra,taxrank="Family")
taxa_names(ps6.ic.nm.ra.fam)<-as.data.frame(tax_table(ps6.ic.nm.ra.fam)[,5])$Family   # update taxa names
relabund.fam<-cbind(as(sample_data(ps6.ic.nm.ra.fam),'data.frame'),as.data.frame(otu_table(ps6.ic.nm.ra.fam))) # data frame of phyla abundance and sample data

ps6.ic.ra.fam<-tax_glom(ps6.ic.ra,taxrank="Family")
taxa_names(ps6.ic.ra.fam)<-as.data.frame(tax_table(ps6.ic.ra.fam)[,5])$Family   # update taxa names
relabund.fam.m<-cbind(as(sample_data(ps6.ic.ra.fam),'data.frame'),as.data.frame(otu_table(ps6.ic.ra.fam))) # data frame of phyla abundance and sample data


#### 3.1.1.1) Across Colony ####
# Phylum level relative abundance #
colony.phy.df <- relabund.phy %>% group_by(colony) %>% summarise_each(funs(mean))
colony.phy.df<-colony.phy.df[,-c(2:15)]

m.colony.phy.df <- melt(colony.phy.df, id.vars = "colony")
m.colony.phy.df$variable<-as.character(m.colony.phy.df$variable)
m.colony.phy.df$Taxon<-ifelse(m.colony.phy.df$value>0.01,m.colony.phy.df$variable,"Low Abundance")

m.colony.phy.df$Taxon <- factor(m.colony.phy.df$Taxon,
                            levels = c("Low Abundance","Cyanobacteria","Synergistetes",
                                       "Epsilonbacteraeota","Verrucomicrobia","Proteobacteria","Fibrobacteres",
                                       "Firmicutes","Bacteroidetes"),ordered = TRUE)

ggplot(m.colony.phy.df, aes(x= colony, y= value, fill = Taxon)) + 
  geom_bar(stat = "identity",col="black") + theme.gg.leg + coord_flip() 

# find families within Firmicutes and Bacteroidetes #
# Firmicutes #
ps6.ic.nm.ra.fam.firm<-subset_taxa(ps6.ic.nm.ra.fam, Phylum=="Firmicutes")
taxa_names(ps6.ic.nm.ra.fam.firm)<-as.data.frame(tax_table(ps6.ic.nm.ra.fam.firm)[,5])$Family   # update taxa names
relabund.fam.firm<-cbind(as(sample_data(ps6.ic.nm.ra.fam.firm),'data.frame'),as.data.frame(otu_table(ps6.ic.nm.ra.fam.firm))) # data frame of phyla abundance and sample data
colony.fam.firm.df <- relabund.fam.firm %>% group_by(colony) %>% summarise_each(funs(mean))
colony.fam.firm.df<-colony.fam.firm.df[,-c(2:15)]
m.colony.fam.firm.df <- melt(colony.fam.firm.df, id.vars = "colony")
m.colony.fam.firm.df$variable<-as.character(m.colony.fam.firm.df$variable)
m.colony.fam.firm.df$Taxon<-ifelse(m.colony.fam.firm.df$value>0.02,m.colony.fam.firm.df$variable,"Low.Firm")
# subtract the sum of abundance of these families from the phylum abundance to get abundance of unknown Firmicutes
unkFirm.Xena<-m.colony.phy.df[m.colony.phy.df$colony=="Xena" & m.colony.phy.df$variable=="Firmicutes", 3] - 
  sum(m.colony.fam.firm.df[m.colony.fam.firm.df$colony=="Xena",3])

unkFirm.Macbeth<-m.colony.phy.df[m.colony.phy.df$colony=="Macbeth" & m.colony.phy.df$variable=="Firmicutes", 3] - 
  sum(m.colony.fam.firm.df[m.colony.fam.firm.df$colony=="Macbeth",3])

unkFirm.Lucy<-m.colony.phy.df[m.colony.phy.df$colony=="Lucy" & m.colony.phy.df$variable=="Firmicutes", 3] - 
  sum(m.colony.fam.firm.df[m.colony.fam.firm.df$colony=="Lucy",3])

unkFirm.Ichabod<-m.colony.phy.df[m.colony.phy.df$colony=="Ichabod" & m.colony.phy.df$variable=="Firmicutes", 3] - 
  sum(m.colony.fam.firm.df[m.colony.fam.firm.df$colony=="Ichabod",3])

unkFirm.Fenty<-m.colony.phy.df[m.colony.phy.df$colony=="Fenty" & m.colony.phy.df$variable=="Firmicutes", 3] - 
  sum(m.colony.fam.firm.df[m.colony.fam.firm.df$colony=="Fenty",3])

unkFirm.Elizabeth<-m.colony.phy.df[m.colony.phy.df$colony=="Elizabeth" & m.colony.phy.df$variable=="Firmicutes", 3] - 
  sum(m.colony.fam.firm.df[m.colony.fam.firm.df$colony=="Elizabeth",3])

unkFirm<-c(unkFirm.Xena,unkFirm.Macbeth,unkFirm.Lucy,unkFirm.Ichabod,unkFirm.Fenty,unkFirm.Elizabeth)
col<-c("Xena","Macbeth","Lucy","Ichabod","Fenty","Elizabeth")
tax<-rep("unkFirm",6)
unkFirm1<-as.data.frame(cbind(col,tax,unkFirm,tax))
colnames(unkFirm1)<-c("colony","variable","value","Taxon")
unkFirm1$value<-as.numeric(as.character(unkFirm1$value))

m.colony.fam.firm.df1<-rbind(m.colony.fam.firm.df,unkFirm1)

# Bacteroidetes #
ps6.ic.nm.ra.fam.bact<-subset_taxa(ps6.ic.nm.ra.fam, Phylum=="Bacteroidetes")
taxa_names(ps6.ic.nm.ra.fam.bact)<-as.data.frame(tax_table(ps6.ic.nm.ra.fam.bact)[,5])$Family   # update taxa names
relabund.fam.bact<-cbind(as(sample_data(ps6.ic.nm.ra.fam.bact),'data.frame'),as.data.frame(otu_table(ps6.ic.nm.ra.fam.bact))) # data frame of phyla abundance and sample data
colony.fam.bact.df <- relabund.fam.bact %>% group_by(colony) %>% summarise_each(funs(mean))
colony.fam.bact.df<-colony.fam.bact.df[,-c(2:15)]
m.colony.fam.bact.df <- melt(colony.fam.bact.df, id.vars = "colony")
m.colony.fam.bact.df$variable<-as.character(m.colony.fam.bact.df$variable)
m.colony.fam.bact.df$Taxon<-ifelse(m.colony.fam.bact.df$value>0.02,m.colony.fam.bact.df$variable,"Low.Bact")

# subtract the sum of abundance of these families from the phylum abundance to get abundance of unknown Bacteroidetes
unkBact.Xena<-m.colony.phy.df[m.colony.phy.df$colony=="Xena" & m.colony.phy.df$variable=="Bacteroidetes", 3] - 
  sum(m.colony.fam.bact.df[m.colony.fam.bact.df$colony=="Xena",3])

unkBact.Macbeth<-m.colony.phy.df[m.colony.phy.df$colony=="Macbeth" & m.colony.phy.df$variable=="Bacteroidetes", 3] - 
  sum(m.colony.fam.bact.df[m.colony.fam.bact.df$colony=="Macbeth",3])

unkBact.Lucy<-m.colony.phy.df[m.colony.phy.df$colony=="Lucy" & m.colony.phy.df$variable=="Bacteroidetes", 3] - 
  sum(m.colony.fam.bact.df[m.colony.fam.bact.df$colony=="Lucy",3])

unkBact.Ichabod<-m.colony.phy.df[m.colony.phy.df$colony=="Ichabod" & m.colony.phy.df$variable=="Bacteroidetes", 3] - 
  sum(m.colony.fam.bact.df[m.colony.fam.bact.df$colony=="Ichabod",3])

unkBact.Fenty<-m.colony.phy.df[m.colony.phy.df$colony=="Fenty" & m.colony.phy.df$variable=="Bacteroidetes", 3] - 
  sum(m.colony.fam.bact.df[m.colony.fam.bact.df$colony=="Fenty",3])

unkBact.Elizabeth<-m.colony.phy.df[m.colony.phy.df$colony=="Elizabeth" & m.colony.phy.df$variable=="Bacteroidetes", 3] - 
  sum(m.colony.fam.bact.df[m.colony.fam.bact.df$colony=="Elizabeth",3])

unkBact<-c(unkBact.Xena,unkBact.Macbeth,unkBact.Lucy,unkBact.Ichabod,unkBact.Fenty,unkBact.Elizabeth)
col<-c("Xena","Macbeth","Lucy","Ichabod","Fenty","Elizabeth")
tax<-rep("unkBact",6)
unkBact1<-as.data.frame(cbind(col,tax,unkBact,tax))
colnames(unkBact1)<-c("colony","variable","value","Taxon")
unkBact1$value<-as.numeric(as.character(unkBact1$value))

m.colony.fam.bact.df1<-rbind(m.colony.fam.bact.df,unkBact1)

# bind with existing phylum relatve abundance data frame
m.colony.famphy.df<-rbind(m.colony.phy.df,m.colony.fam.bact.df1,m.colony.fam.firm.df1)

# remove rows of Firmicutes and Bacteroidetes abundance
m.colony.famphy.df1<-m.colony.famphy.df[m.colony.famphy.df$variable!="Firmicutes" & m.colony.famphy.df$variable!="Bacteroidetes",]


fam.phy.colours<-c("Low Abundance"="#000000", "Cyanobacteria"="#ffff33", "Synergistetes"="#ff7f00",
                   "Proteobacteria"="#e41a1c", "Fibrobacteres"="#377eb8","Firmicutes"="#54278f","Bacteroidetes"="#238b45",
                   "unkFirm"="#efedf5","Low.Firm"="#bcbddc", "p-2534-18B5_gut_group"="#a1d99b", "Paludibacteraceae"="#74c476",
                   "Rikenellaceae"="#a1d99b","p-251-o5"="#74c476", "Muribaculaceae"="#31a354", 
                   "unkBact"="#e5f5e0", "Low.Bact"="#c7e9c0", "Veillonellaceae"="#dadaeb", "Family_XIII"="#9e9ac8",
                   "Christensenellaceae"="#807dba", "Lachnospiraceae"="#6a51a3", "Erysipelotrichaceae"="#4a1486",
                   "Ruminococcaceae"="#3f007d", "Prevotellaceae"="#006d2c", "Epsilonbacteraeota"="#CDB79E")

"Lactobacillaceae"="#3f007d",

m.colony.famphy.df1$Taxon <- factor(m.colony.famphy.df1$Taxon,
                                levels = c("Low Abundance","Cyanobacteria","Synergistetes",
                                           "Proteobacteria","Fibrobacteres",
                                           "unkFirm","Low.Firm", "Veillonellaceae", "Family_XIII",
                                           "Christensenellaceae", "Lachnospiraceae", "Erysipelotrichaceae",
                                           "Ruminococcaceae",
                                           "unkBact", "Low.Bact",
                                           "p-2534-18B5_gut_group", "Paludibacteraceae",
                                           "Rikenellaceae","p-251-o5", "Muribaculaceae", "Prevotellaceae"),ordered = TRUE)

#### Stacked barchart across colony ####
pdf(file="~Manuscript/Figures/rel.abund.colony.pdf",
    width=12,height=8,bg = "transparent")
ggplot(m.colony.famphy.df1, aes(x= colony, y= value, fill = Taxon)) + 
  geom_bar(stat = "identity",col="black") + theme.gg.leg + coord_flip() +
  scale_fill_manual(values=fam.phy.colours)
dev.off()

#### 3.1.1.2) Across subcaste ####
subcaste.phy.df <- relabund.phy %>% group_by(subcaste) %>% summarise_each(funs(mean))
subcaste.phy.df<-subcaste.phy.df[,-c(2:15)]
m.subcaste.phy.df <- melt(subcaste.phy.df, id.vars = "subcaste")
m.subcaste.phy.df$variable<-as.character(m.subcaste.phy.df$variable)
m.subcaste.phy.df$Taxon<-ifelse(m.subcaste.phy.df$value>0.01,m.subcaste.phy.df$variable,"Low Abundance")

m.subcaste.phy.df$Taxon <- factor(m.subcaste.phy.df$Taxon,
                                levels = c("Low Abundance","Cyanobacteria","Synergistetes",
                                           "Epsilonbacteraeota","Verrucomicrobia","Proteobacteria","Fibrobacteres",
                                           "Firmicutes","Bacteroidetes"),ordered = TRUE)

m.subcaste.phy.df$subcaste <- factor(m.subcaste.phy.df$subcaste,
                                 levels = c("worker","soldier","disperser",
                                            "breeding_male","queen","mouse"),ordered = TRUE)

ggplot(m.subcaste.phy.df, aes(x= subcaste, y= value, fill = Taxon)) + 
  geom_bar(stat = "identity",col="black") + theme.gg.leg + coord_flip() +
  scale_fill_manual(values=phylum.colors)

# Firmicutes #
subcaste.fam.firm.df <- relabund.fam.firm %>% group_by(subcaste) %>% summarise_each(funs(mean))
subcaste.fam.firm.df<-subcaste.fam.firm.df[,-c(2:15)]
m.subcaste.fam.firm.df <- melt(subcaste.fam.firm.df, id.vars = "subcaste")
m.subcaste.fam.firm.df$variable<-as.character(m.subcaste.fam.firm.df$variable)
m.subcaste.fam.firm.df$Taxon<-ifelse(m.subcaste.fam.firm.df$value>0.02,m.subcaste.fam.firm.df$variable,"Low.Firm")
# subtract the sum of abundance of these families from the phylum abundance to get abundance of unknown Firmicutes
unkFirm.queen<-m.subcaste.phy.df[m.subcaste.phy.df$subcaste=="queen" & m.subcaste.phy.df$variable=="Firmicutes", 3] - 
  sum(m.subcaste.fam.firm.df[m.subcaste.fam.firm.df$subcaste=="queen",3])

unkFirm.bmale<-m.subcaste.phy.df[m.subcaste.phy.df$subcaste=="breeding_male" & m.subcaste.phy.df$variable=="Firmicutes", 3] - 
  sum(m.subcaste.fam.firm.df[m.subcaste.fam.firm.df$subcaste=="breeding_male",3])

unkFirm.disperser<-m.subcaste.phy.df[m.subcaste.phy.df$subcaste=="disperser" & m.subcaste.phy.df$variable=="Firmicutes", 3] - 
  sum(m.subcaste.fam.firm.df[m.subcaste.fam.firm.df$subcaste=="disperser",3])

unkFirm.soldier<-m.subcaste.phy.df[m.subcaste.phy.df$subcaste=="soldier" & m.subcaste.phy.df$variable=="Firmicutes", 3] - 
  sum(m.subcaste.fam.firm.df[m.subcaste.fam.firm.df$subcaste=="soldier",3])

unkFirm.worker<-m.subcaste.phy.df[m.subcaste.phy.df$subcaste=="worker" & m.subcaste.phy.df$variable=="Firmicutes", 3] - 
  sum(m.subcaste.fam.firm.df[m.subcaste.fam.firm.df$subcaste=="worker",3])

unkFirm.subcaste<-c(unkFirm.queen,unkFirm.bmale,unkFirm.disperser,unkFirm.soldier,unkFirm.worker)
col<-c("queen","breeding_male","disperser","soldier","worker")
tax<-rep("unkFirm",5)
unkFirm1.subcaste<-as.data.frame(cbind(col,tax,unkFirm.subcaste,tax))
colnames(unkFirm1.subcaste)<-c("subcaste","variable","value","Taxon")
unkFirm1.subcaste$value<-as.numeric(as.character(unkFirm1.subcaste$value))

m.subcaste.fam.firm.df1<-rbind(m.subcaste.fam.firm.df,unkFirm1.subcaste)

# Bacteroidetes #
subcaste.fam.bact.df <- relabund.fam.bact %>% group_by(subcaste) %>% summarise_each(funs(mean))
subcaste.fam.bact.df<-subcaste.fam.bact.df[,-c(2:15)]
m.subcaste.fam.bact.df <- melt(subcaste.fam.bact.df, id.vars = "subcaste")
m.subcaste.fam.bact.df$variable<-as.character(m.subcaste.fam.bact.df$variable)
m.subcaste.fam.bact.df$Taxon<-ifelse(m.subcaste.fam.bact.df$value>0.02,m.subcaste.fam.bact.df$variable,"Low.Bact")
# subtract the sum of abundance of these families from the phylum abundance to get abundance of unknown Bacticutes
unkBact.queen<-m.subcaste.phy.df[m.subcaste.phy.df$subcaste=="queen" & m.subcaste.phy.df$variable=="Bacteroidetes", 3] - 
  sum(m.subcaste.fam.bact.df[m.subcaste.fam.bact.df$subcaste=="queen",3])

unkBact.bmale<-m.subcaste.phy.df[m.subcaste.phy.df$subcaste=="breeding_male" & m.subcaste.phy.df$variable=="Bacteroidetes", 3] - 
  sum(m.subcaste.fam.bact.df[m.subcaste.fam.bact.df$subcaste=="breeding_male",3])

unkBact.disperser<-m.subcaste.phy.df[m.subcaste.phy.df$subcaste=="disperser" & m.subcaste.phy.df$variable=="Bacteroidetes", 3] - 
  sum(m.subcaste.fam.bact.df[m.subcaste.fam.bact.df$subcaste=="disperser",3])

unkBact.soldier<-m.subcaste.phy.df[m.subcaste.phy.df$subcaste=="soldier" & m.subcaste.phy.df$variable=="Bacteroidetes", 3] - 
  sum(m.subcaste.fam.bact.df[m.subcaste.fam.bact.df$subcaste=="soldier",3])

unkBact.worker<-m.subcaste.phy.df[m.subcaste.phy.df$subcaste=="worker" & m.subcaste.phy.df$variable=="Bacteroidetes", 3] - 
  sum(m.subcaste.fam.bact.df[m.subcaste.fam.bact.df$subcaste=="worker",3])

unkBact.subcaste<-c(unkBact.queen,unkBact.bmale,unkBact.disperser,unkBact.soldier,unkBact.worker)
col<-c("queen","breeding_male","disperser","soldier","worker")
tax<-rep("unkBact",5)
unkBact1.subcaste<-as.data.frame(cbind(col,tax,unkBact.subcaste,tax))
colnames(unkBact1.subcaste)<-c("subcaste","variable","value","Taxon")
unkBact1.subcaste$value<-as.numeric(as.character(unkBact1.subcaste$value))

m.subcaste.fam.bact.df1<-rbind(m.subcaste.fam.bact.df,unkBact1.subcaste)

# bind with existing phylum relatve abundance data frame
m.subcaste.famphy.df<-rbind(m.subcaste.phy.df,m.subcaste.fam.bact.df1,m.subcaste.fam.firm.df1)

# remove rows of Firmicutes and Bacteroidetes abundance
m.subcaste.famphy.df1<-m.subcaste.famphy.df[m.subcaste.famphy.df$variable!="Firmicutes" & m.subcaste.famphy.df$variable!="Bacteroidetes",]

#### Stacked barchart across subcaste ####

m.subcaste.famphy.df1$Taxon <- factor(m.subcaste.famphy.df1$Taxon,
                                    levels = c("Low Abundance","Cyanobacteria","Synergistetes",
                                               "Proteobacteria","Fibrobacteres",
                                               "unkFirm","Low.Firm", "p-2534-18B5_gut_group", "Paludibacteraceae",
                                               "Rikenellaceae","p-251-o5", "Muribaculaceae", 
                                               "unkBact", "Low.Bact", "Veillonellaceae", "Family_XIII",
                                               "Christensenellaceae", "Lachnospiraceae", "Erysipelotrichaceae",
                                               "Ruminococcaceae", "Prevotellaceae"),ordered = TRUE)

m.subcaste.famphy.df1$Taxon <- factor(m.subcaste.famphy.df1$Taxon,
                                    levels = c("Low Abundance","Cyanobacteria","Synergistetes",
                                               "Proteobacteria","Fibrobacteres",
                                               "unkFirm","Low.Firm", "Veillonellaceae", "Family_XIII",
                                               "Christensenellaceae", "Lachnospiraceae", "Erysipelotrichaceae",
                                               "Ruminococcaceae",
                                               "unkBact", "Low.Bact",
                                               "p-2534-18B5_gut_group", "Paludibacteraceae",
                                               "Rikenellaceae","p-251-o5", "Muribaculaceae", "Prevotellaceae"),ordered = TRUE)

pdf(file="~Manuscript/Figures/rel.abund.subcaste.pdf",
    width=12,height=8,bg = "transparent")
ggplot(m.subcaste.famphy.df1, aes(x= subcaste, y= value, fill = Taxon)) + 
  geom_bar(stat = "identity",col="black") + theme.gg.leg + coord_flip() +
  scale_fill_manual(values=fam.phy.colours)
dev.off()

#### 3.1.1.2) Across species ####
spe.phy.df <- relabund.phy.m %>% group_by(spe) %>% summarise_each(funs(mean))
spe.phy.df<-spe.phy.df[,-c(2:15)]
m.spe.phy.df <- melt(spe.phy.df, id.vars = "spe")
m.spe.phy.df$variable<-as.character(m.spe.phy.df$variable)
m.spe.phy.df$Taxon<-ifelse(m.spe.phy.df$value>0.01,m.spe.phy.df$variable,"Low Abundance")

m.spe.phy.df$Taxon <- factor(m.spe.phy.df$Taxon,
                                  levels = c("Low Abundance","Epsilonbacteraeota",
                                             "Proteobacteria","Fibrobacteres",
                                             "Firmicutes","Bacteroidetes"),ordered = TRUE)

m.spe.phy.df$spe <- factor(m.spe.phy.df$spe,
                                     levels = c("nmr","mouse"),ordered = TRUE)

ggplot(m.spe.phy.df, aes(x= spe, y= value, fill = Taxon)) + 
  geom_bar(stat = "identity",col="black") + theme.gg.leg + coord_flip() +
  scale_fill_manual(values=phylum.colors)

# find families within Firmicutes and Bacteroidetes #
# Firmicutes #
ps6.ic.ra.fam.firm<-subset_taxa(ps6.ic.ra.fam, Phylum=="Firmicutes")
taxa_names(ps6.ic.ra.fam.firm)<-as.data.frame(tax_table(ps6.ic.ra.fam.firm)[,5])$Family   # update taxa names
relabund.fam.firm<-cbind(as(sample_data(ps6.ic.ra.fam.firm),'data.frame'),as.data.frame(otu_table(ps6.ic.ra.fam.firm))) # data frame of phyla abundance and sample data
spe.fam.firm.df <- relabund.fam.firm %>% group_by(spe) %>% summarise_each(funs(mean))
spe.fam.firm.df<-spe.fam.firm.df[,-c(2:15)]
m.spe.fam.firm.df <- melt(spe.fam.firm.df, id.vars = "spe")
m.spe.fam.firm.df$variable<-as.character(m.spe.fam.firm.df$variable)
m.spe.fam.firm.df$Taxon<-ifelse(m.spe.fam.firm.df$value>0.02,m.spe.fam.firm.df$variable,"Low.Firm")
# subtract the sum of abundance of these families from the phylum abundance to get abundance of unknown Firmicutes
unkFirm.nmr<-m.spe.phy.df[m.spe.phy.df$spe=="nmr" & m.spe.phy.df$variable=="Firmicutes", 3] - 
  sum(m.spe.fam.firm.df[m.spe.fam.firm.df$spe=="nmr",3])

unkFirm.mouse<-m.spe.phy.df[m.spe.phy.df$spe=="mouse" & m.spe.phy.df$variable=="Firmicutes", 3] - 
  sum(m.spe.fam.firm.df[m.spe.fam.firm.df$spe=="mouse",3])

unkFirm<-c(unkFirm.nmr,unkFirm.mouse)
col<-c("nmr","mouse")
tax<-rep("unkFirm",2)
unkFirm1<-as.data.frame(cbind(col,tax,unkFirm,tax))
colnames(unkFirm1)<-c("spe","variable","value","Taxon")
unkFirm1$value<-as.numeric(as.character(unkFirm1$value))

m.spe.fam.firm.df1<-rbind(m.spe.fam.firm.df,unkFirm1)

# Bacteroidetes #
ps6.ic.ra.fam.bact<-subset_taxa(ps6.ic.ra.fam, Phylum=="Bacteroidetes")
taxa_names(ps6.ic.ra.fam.bact)<-as.data.frame(tax_table(ps6.ic.ra.fam.bact)[,5])$Family   # update taxa names
relabund.fam.bact<-cbind(as(sample_data(ps6.ic.ra.fam.bact),'data.frame'),as.data.frame(otu_table(ps6.ic.ra.fam.bact))) # data frame of phyla abundance and sample data
spe.fam.bact.df <- relabund.fam.bact %>% group_by(spe) %>% summarise_each(funs(mean))
spe.fam.bact.df<-spe.fam.bact.df[,-c(2:15)]
m.spe.fam.bact.df <- melt(spe.fam.bact.df, id.vars = "spe")
m.spe.fam.bact.df$variable<-as.character(m.spe.fam.bact.df$variable)
m.spe.fam.bact.df$Taxon<-ifelse(m.spe.fam.bact.df$value>0.02,m.spe.fam.bact.df$variable,"Low.Bact")

# subtract the sum of abundance of these families from the phylum abundance to get abundance of unknown Bacteroidetes
unkBact.nmr<-m.spe.phy.df[m.spe.phy.df$spe=="nmr" & m.spe.phy.df$variable=="Bacteroidetes", 3] - 
  sum(m.spe.fam.bact.df[m.spe.fam.bact.df$spe=="nmr",3])

unkBact.mouse<-m.spe.phy.df[m.spe.phy.df$spe=="mouse" & m.spe.phy.df$variable=="Bacteroidetes", 3] - 
  sum(m.spe.fam.bact.df[m.spe.fam.bact.df$spe=="mouse",3])

unkBact<-c(unkBact.nmr,unkBact.mouse)
col<-c("nmr","mouse")
tax<-rep("unkBact",2)
unkBact1<-as.data.frame(cbind(col,tax,unkBact,tax))
colnames(unkBact1)<-c("spe","variable","value","Taxon")
unkBact1$value<-as.numeric(as.character(unkBact1$value))

m.spe.fam.bact.df1<-rbind(m.spe.fam.bact.df,unkBact1)

# bind with existing phylum relatve abundance data frame
m.spe.famphy.df<-rbind(m.spe.phy.df,m.spe.fam.bact.df1,m.spe.fam.firm.df1)

# remove rows of Firmicutes and Bacteroidetes abundance
m.spe.famphy.df1<-m.spe.famphy.df[m.spe.famphy.df$variable!="Firmicutes" & m.spe.famphy.df$variable!="Bacteroidetes",]


fam.phy.colours<-c("Low Abundance"="#000000","Epsilonbacteraeota"="#feb24c",
                   "Proteobacteria"="#a63603", "Fibrobacteres"="#08519c",
                   "unkFirm"="#efedf5","Low.Firm"="#bcbddc", "Christensenellaceae"="#9e9ac8",
                   "Lachnospiraceae"="#807dba","Ruminococcaceae"="#6a51a3","Erysipelotrichaceae"="#54278f",
                   "Lactobacillaceae"="#3f007d",
                   "unkBact"="#e5f5e0", "Low.Bact"="#c7e9c0", "Rikenellaceae"="#74c476",
                   "p-251-o5"="#41ab5d","Muribaculaceae"="#238b45","Prevotellaceae"="#006d2c")

m.spe.famphy.df1$Taxon <- factor(m.spe.famphy.df1$Taxon,
                                    levels = c("Low Abundance","Epsilonbacteraeota",
                                               "Proteobacteria","Fibrobacteres",
                                               "unkFirm","Low.Firm", "Christensenellaceae","Lachnospiraceae", 
                                               "Ruminococcaceae","Erysipelotrichaceae", "Lactobacillaceae",
                                               "unkBact", "Low.Bact", "Rikenellaceae","p-251-o5", 
                                               "Muribaculaceae", "Prevotellaceae"),ordered = TRUE)

#### Stacked barchart across species ####
pdf(file="~Manuscript/Figures/rel.abund.spe.pdf",
    width=12,height=8,bg = "transparent")
ggplot(m.spe.famphy.df1, aes(x= spe, y= value, fill = Taxon)) + 
  geom_bar(stat = "identity",col="black") + theme.gg.leg + coord_flip() +
  scale_fill_manual(values=fam.phy.colours)
dev.off()

# across sex #
sex.phy.df <- relabund.phy %>% group_by(sex) %>% summarise_each(funs(mean))
sex.phy.df<-sex.phy.df[,-c(2:12)]

m.sex.phy.df <- melt(sex.phy.df, id.vars = "sex")
m.sex.phy.df$variable<-as.character(m.sex.phy.df$variable)
m.sex.phy.df$Taxon<-ifelse(m.sex.phy.df$value>0.01,m.sex.phy.df$variable,"Low Abundance")

m.sex.phy.df$Taxon <- factor(m.sex.phy.df$Taxon,
                                levels = c("Low Abundance","Cyanobacteria","Synergistetes",
                                           "Epsilonbacteraeota","Verrucomicrobia","Proteobacteria","Fibrobacteres",
                                           "Firmicutes","Bacteroidetes"),ordered = TRUE)

ggplot(m.sex.phy.df, aes(x= sex, y= value, fill = Taxon)) + 
  geom_bar(stat = "identity",col="black") + theme.gg.leg + coord_flip() 

# sex in mouse #
ps6.mouse.ra.phy<-tax_glom(ps6.mouse.ra,taxrank="Phylum")
taxa_names(ps6.mouse.ra.phy)<-as.data.frame(tax_table(ps6.mouse.ra.phy)[,2])$Phylum   # update taxa names
relabund.phy.mouse<-cbind(as(sample_data(ps6.mouse.ra.phy),'data.frame'),as.data.frame(otu_table(ps6.mouse.ra.phy))) # data frame of phyla abundance and sample data

sex.phy.mouse.df <- relabund.phy.mouse %>% group_by(sex) %>% summarise_each(funs(mean))
sex.phy.mouse.df<-sex.phy.mouse.df[,-c(2:12)]

m.sex.phy.mouse.df <- melt(sex.phy.mouse.df, id.vars = "sex")
m.sex.phy.mouse.df$variable<-as.character(m.sex.phy.mouse.df$variable)
m.sex.phy.mouse.df$Taxon<-ifelse(m.sex.phy.mouse.df$value>0.005,m.sex.phy.mouse.df$variable,"Low Abundance")

ggplot(m.sex.phy.mouse.df, aes(x= sex, y= value, fill = Taxon)) + 
  geom_bar(stat = "identity",col="black") + theme.gg.leg + coord_flip() 


#### 4) Differential abundance testing ####
# Which bacterial taxa exhibit differential abundance in response to colony, subcaste, sex?
ps6.ic.nm<-prune_taxa(taxa_sums(ps6.ic.nm)>0,ps6.ic.nm); ntaxa(ps6.ic.nm) 
ps6.ic<-prune_taxa(taxa_sums(ps6.ic)>0,ps6.ic); ntaxa(ps6.ic)
sample_data(ps6.ic)$spe<-ifelse(sample_data(ps6.ic)$colony=="mouse","mouse","nmr")
ps6.ic.2<-prune_taxa(taxa_sums(ps6.ic.2)>0,ps6.ic.2); ntaxa(ps6.ic.2) 
ps6.p<-prune_taxa(taxa_sums(ps6.p)>0,ps6.p); ntaxa(ps6.p)
ps6.p.da<-subset_samples(ps6.p, subcaste != "T2")
ps6.p.da<-prune_taxa(taxa_sums(ps6.p.da)>0,ps6.p.da); ntaxa(ps6.p.da)
sample_data(ps6.p.da)$sex.time<-interaction(sample_data(ps6.p.da)$subcaste,sample_data(ps6.p.da)$sex)

ps6.p.t1<-subset_samples(ps6.p, subcaste == "T1")
ps6.p.t1<-prune_taxa(taxa_sums(ps6.p.t1)>0,ps6.p.t1); ntaxa(ps6.p.t1)

ps6.p.t3<-subset_samples(ps6.p, subcaste == "T3")
ps6.p.t3<-prune_taxa(taxa_sums(ps6.p.t3)>0,ps6.p.t3); ntaxa(ps6.p.t3)

ps6.mouse<-subset_samples(ps6, subcaste == "mouse")
ps6.mouse<-prune_taxa(taxa_sums(ps6.mouse)>0,ps6.mouse); ntaxa(ps6.mouse)

## Taxonomic agglomerations ##
# use raw count data from thresholded phyloseq onjects
# tax.glom by Phylum #
ps6.ic.nm.phy<-tax_glom(ps6.ic.nm,taxrank="Phylum")
taxa_names(ps6.ic.nm.phy)<-as.data.frame(tax_table(ps6.ic.nm.phy)[,2])$Phylum  # update taxa names

ps6.ic.phy<-tax_glom(ps6.ic,taxrank="Phylum")
taxa_names(ps6.ic.phy)<-as.data.frame(tax_table(ps6.ic.phy)[,2])$Phylum  # update taxa names

ps6.ic.2.phy<-tax_glom(ps6.ic.2,taxrank="Phylum")
taxa_names(ps6.ic.2.phy)<-as.data.frame(tax_table(ps6.ic.2.phy)[,2])$Phylum  # update taxa names

ps6.p.phy<-tax_glom(ps6.p,taxrank="Phylum")
taxa_names(ps6.p.phy)<-as.data.frame(tax_table(ps6.p.phy)[,2])$Phylum  # update taxa names

ps6.p.da.phy<-tax_glom(ps6.p.da,taxrank="Phylum")
taxa_names(ps6.p.da.phy)<-as.data.frame(tax_table(ps6.p.da.phy)[,2])$Phylum  # update taxa names

ps6.p.t1.phy<-tax_glom(ps6.p.t1,taxrank="Phylum")
taxa_names(ps6.p.t1.phy)<-as.data.frame(tax_table(ps6.p.t1.phy)[,2])$Phylum  # update taxa names

ps6.p.t3.phy<-tax_glom(ps6.p.t3,taxrank="Phylum")
taxa_names(ps6.p.t3.phy)<-as.data.frame(tax_table(ps6.p.t3.phy)[,2])$Phylum  # update taxa names

ps6.mouse.phy<-tax_glom(ps6.mouse,taxrank="Phylum")
taxa_names(ps6.mouse.phy)<-as.data.frame(tax_table(ps6.mouse.phy)[,2])$Phylum  # update taxa names

# tax.glom by Class #
ps6.ic.nm.cla<-tax_glom(ps6.ic.nm,taxrank="Class")
taxa_names(ps6.ic.nm.cla)<-as.data.frame(tax_table(ps6.ic.nm.cla)[,3])$Class  # update taxa names

ps6.ic.cla<-tax_glom(ps6.ic,taxrank="Class")
taxa_names(ps6.ic.cla)<-as.data.frame(tax_table(ps6.ic.cla)[,3])$Class  # update taxa names

ps6.ic.2.cla<-tax_glom(ps6.ic.2,taxrank="Class")
taxa_names(ps6.ic.2.cla)<-as.data.frame(tax_table(ps6.ic.2.cla)[,3])$Class  # update taxa names

ps6.p.cla<-tax_glom(ps6.p,taxrank="Class")
taxa_names(ps6.p.cla)<-as.data.frame(tax_table(ps6.p.cla)[,3])$Class  # update taxa names

ps6.p.da.cla<-tax_glom(ps6.p.da,taxrank="Class")
taxa_names(ps6.p.da.cla)<-as.data.frame(tax_table(ps6.p.da.cla)[,3])$Class  # update taxa names

ps6.mouse.cla<-tax_glom(ps6.mouse,taxrank="Class")
taxa_names(ps6.mouse.cla)<-as.data.frame(tax_table(ps6.mouse.cla)[,3])$Class  # update taxa names

# tax.glom by Order #
ps6.ic.nm.ord<-tax_glom(ps6.ic.nm,taxrank="Order")
taxa_names(ps6.ic.nm.ord)<-as.data.frame(tax_table(ps6.ic.nm.ord)[,4])$Order  # update taxa names

ps6.ic.ord<-tax_glom(ps6.ic,taxrank="Order")
taxa_names(ps6.ic.ord)<-as.data.frame(tax_table(ps6.ic.ord)[,4])$Order  # update taxa names

ps6.ic.2.ord<-tax_glom(ps6.ic.2,taxrank="Order")
taxa_names(ps6.ic.2.ord)<-as.data.frame(tax_table(ps6.ic.2.ord)[,4])$Order  # update taxa names

ps6.p.ord<-tax_glom(ps6.p,taxrank="Order")
taxa_names(ps6.p.ord)<-as.data.frame(tax_table(ps6.p.ord)[,4])$Order  # update taxa names

ps6.mouse.ord<-tax_glom(ps6.mouse,taxrank="Order")
taxa_names(ps6.mouse.ord)<-as.data.frame(tax_table(ps6.mouse.ord)[,4])$Order  # update taxa names

# tax.glom by Family #
ps6.ic.nm.fam<-tax_glom(ps6.ic.nm,taxrank="Family")
taxa_names(ps6.ic.nm.fam)<-as.data.frame(tax_table(ps6.ic.nm.fam)[,5])$Family  # update taxa names

ps6.ic.fam<-tax_glom(ps6.ic,taxrank="Family")
taxa_names(ps6.ic.fam)<-as.data.frame(tax_table(ps6.ic.fam)[,5])$Family  # update taxa names

ps6.ic.2.fam<-tax_glom(ps6.ic.2,taxrank="Family")
taxa_names(ps6.ic.2.fam)<-as.data.frame(tax_table(ps6.ic.2.fam)[,5])$Family  # update taxa names

ps6.p.fam<-tax_glom(ps6.p,taxrank="Family")
taxa_names(ps6.p.fam)<-as.data.frame(tax_table(ps6.p.fam)[,5])$Family  # update taxa names

ps6.p.da.fam<-tax_glom(ps6.p.da,taxrank="Family")
taxa_names(ps6.p.da.fam)<-as.data.frame(tax_table(ps6.p.da.fam)[,5])$Family  # update taxa names

ps6.mouse.fam<-tax_glom(ps6.mouse,taxrank="Family")
taxa_names(ps6.mouse.fam)<-as.data.frame(tax_table(ps6.mouse.fam)[,5])$Family  # update taxa names

ps6.p.t1.fam<-tax_glom(ps6.p.t1,taxrank="Family")
taxa_names(ps6.p.t1.fam)<-as.data.frame(tax_table(ps6.p.t1.fam)[,5])$Phylum  # update taxa names

ps6.p.t3.fam<-tax_glom(ps6.p.t3,taxrank="Family")
taxa_names(ps6.p.t3.fam)<-as.data.frame(tax_table(ps6.p.t3.fam)[,5])$Phylum  # update taxa names

# tax.glom by Genus #
ps6.ic.nm.gen<-tax_glom(ps6.ic.nm,taxrank="Genus")
taxa_names(ps6.ic.nm.gen)<-as.data.frame(tax_table(ps6.ic.nm.gen)[,6])$Genus  # update taxa names

ps6.ic.gen<-tax_glom(ps6.ic,taxrank="Genus")
taxa_names(ps6.ic.gen)<-as.data.frame(tax_table(ps6.ic.gen)[,6])$Genus  # update taxa names

ps6.ic.2.gen<-tax_glom(ps6.ic.2,taxrank="Genus")
taxa_names(ps6.ic.2.gen)<-as.data.frame(tax_table(ps6.ic.2.gen)[,6])$Genus  # update taxa names

ps6.p.gen<-tax_glom(ps6.p,taxrank="Genus")
taxa_names(ps6.p.gen)<-as.data.frame(tax_table(ps6.p.gen)[,6])$Genus  # update taxa names

ps6.mouse.gen<-tax_glom(ps6.mouse,taxrank="Genus")
taxa_names(ps6.mouse.gen)<-as.data.frame(tax_table(ps6.mouse.gen)[,6])$Genus  # update taxa names


##### 4.1) Phylum level differential abundance testing ##### 
dds.phy.nm <-phyloseq_to_deseq2(ps6.ic.nm.phy, ~ colony + sex + subcaste + weight + age + rank) # create full model without interactions
dds.phy.nm = estimateSizeFactors(dds.phy.nm, geoMeans = apply(counts(dds.phy.nm), 1, gm_mean))

dds.phy.colony.pval<-DESeq(dds.phy.nm,test="LRT",reduced= ~ sex + subcaste + weight + age + rank) # perform LRT to obtain p value #
res.dds.phy.colony.pval = cbind(as(results(dds.phy.colony.pval), "data.frame"), as(tax_table(ps6.ic.nm.phy)[rownames(dds.phy.colony.pval), ], "matrix"))
dds.phy.subcaste.pval<-DESeq(dds.phy.nm,test="LRT",reduced= ~ colony + sex + weight + age + rank) # perform LRT to obtain p value #
res.dds.phy.subcaste.pval = cbind(as(results(dds.phy.subcaste.pval), "data.frame"), as(tax_table(ps6.ic.nm.phy)[rownames(dds.phy.subcaste.pval), ], "matrix"))
dds.phy.sex.pval<-DESeq(dds.phy.nm,test="LRT",reduced= ~ subcaste + colony) # perform LRT to obtain p value #
dds.phy.sex.lfce<-DESeq(dds.phy.nm,test="Wald",fitType="parametric") # perform Wald test to obtain lfce #
res.dds.phy.sex.pval = cbind(as(results(dds.phy.sex.pval), "data.frame"), as(tax_table(ps6.ic.nm.phy)[rownames(dds.phy.sex.pval), ], "matrix"))
res.dds.phy.sex.lfce = as(results(dds.phy.sex.lfce,contrast=c("sex","male","female")),'data.frame')
res.dds.phy.sex.lfce$Phylum<-rownames(res.dds.phy.sex.lfce)
dds.phy.weight.pval<-DESeq(dds.phy.nm,test="LRT",reduced= ~ colony + sex + subcaste + age + rank) # perform LRT to obtain p value #
res.dds.phy.weight.pval = cbind(as(results(dds.phy.weight.pval), "data.frame"), as(tax_table(ps6.ic.nm.phy)[rownames(dds.phy.weight.pval), ], "matrix"))
dds.phy.age.pval<-DESeq(dds.phy.nm,test="LRT",reduced= ~ colony + sex + subcaste + weight + rank) # perform LRT to obtain p value #
res.dds.phy.age.pval = cbind(as(results(dds.phy.age.pval), "data.frame"), as(tax_table(ps6.ic.nm.phy)[rownames(dds.phy.age.pval), ], "matrix"))
dds.phy.rank.pval<-DESeq(dds.phy.nm,test="LRT",reduced= ~ colony + sex + subcaste + weight + age) # perform LRT to obtain p value #
res.dds.phy.rank.pval = cbind(as(results(dds.phy.rank.pval), "data.frame"), as(tax_table(ps6.ic.nm.phy)[rownames(dds.phy.rank.pval), ], "matrix"))

dds.phy.spe.ic <-phyloseq_to_deseq2(ps6.ic.phy, ~ spe) # create full model without interactions
dds.phy.spe.ic = estimateSizeFactors(dds.phy.spe.ic, geoMeans = apply(counts(dds.phy.spe.ic), 1, gm_mean))
dds.phy.spe.ic.pval<-DESeq(dds.phy.spe.ic,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
dds.phy.spe.lfce<-DESeq(dds.phy.spe.ic,test="Wald",fitType="parametric")
res.dds.phy.spe.pval = cbind(as(results(dds.phy.spe.ic.pval), "data.frame"), as(tax_table(ps6.ic.phy)[rownames(dds.phy.spe.ic.pval), ], "matrix"))
res.dds.phy.spe.lfce = as(results(dds.phy.spe.lfce,contrast=c("spe","nmr","mouse")),'data.frame')
res.dds.phy.spe.lfce$Phylum<-rownames(res.dds.phy.spe.lfce)

dds.phy.mouse <-phyloseq_to_deseq2(ps6.mouse.phy, ~ sex) # create full model 
dds.phy.mouse = estimateSizeFactors(dds.phy.mouse, geoMeans = apply(counts(dds.phy.mouse), 1, gm_mean))
dds.phy.mouse.sex.pval<-DESeq(dds.phy.mouse,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
dds.phy.mouse.sex.lfce<-DESeq(dds.phy.mouse,test="Wald",fitType="parametric") # perform Wald test to obtain lfce #
res.dds.phy.mouse.sex.pval = cbind(as(results(dds.phy.mouse.sex.pval), "data.frame"), as(tax_table(ps6.mouse.phy)[rownames(dds.phy.mouse.sex.pval), ], "matrix"))
res.dds.phy.mouse.sex.lfce = as(results(dds.phy.mouse.sex.lfce,contrast=c("sex","male","female")),'data.frame')
res.dds.phy.mouse.sex.lfce$Phylum<-rownames(res.dds.phy.mouse.sex.lfce)

# combine results:
# Colony (p), Subcaste (p), Sex (p,lfce), Subcaste:Colony (p), Colony:Sex (p), 
# Subcaste:Sex(p), Species (p, lfce), SexMouse (p,lfce)

res.phy.ic<-cbind(as(tax_table(ps6.ic.nm.phy)[rownames(dds.phy.nm), ], "matrix"),
                  res.dds.phy.colony.pval[,6],
                  res.dds.phy.subcaste.pval[,6],
                  res.dds.phy.sex.lfce[,c(2)],
                  res.dds.phy.sex.pval[,6],
                  res.dds.phy.weight.pval[,c(2,6)],
                  res.dds.phy.age.pval[,c(2,6)],
                  res.dds.phy.rank.pval[,c(2,6)])

res.phy.spe<-res.dds.phy.spe.pval[,c(8,2,6)]
res.phy.mousesex<-res.dds.phy.mouse.sex.pval[,c(8,2,6)]

res.phy.tot1<-merge(res.phy.ic,res.phy.spe,by="Phylum",all=T)
res.phy.tot2<-merge(res.phy.tot1,res.phy.mousesex,by="Phylum",all=T)

# add relative abundance of taxa in entire IC dataset #
phy.ra = transform_sample_counts(ps6.ic.phy, rel.abund)
phy.ra <-cbind(as(sample_data(phy.ra),'data.frame'),as.data.frame(otu_table(phy.ra))) # data frame of phyla abundance and sample data
df1.phy.ra <- phy.ra[,-c(1:16)] %>% summarise_all(funs(mean))
mdf1.phy.ra <- melt(df1.phy.ra)
colnames(mdf1.phy.ra)<-c("Phylum","rel.abund")
res.phy.tot<-merge(mdf1.phy.ra,res.phy.tot2,by="Phylum",all=T)
colnames(res.phy.tot)<-c("Phylum","Relative Abundance","Domain","Class","Order","Family","Genus","Colony (P DESeq2)",
                         "Social Phenotype (P DESeq2)","Sex (LFCE)", "Sex (P DESeq2)",
                         "Weight (LFCE)","Weight (P DESeq2)","Age (LFCE)","Age (P DESeq2)","Rank (LFCE)","Rank (P DESeq2)",
                         "Species (LFCE)", "Species (P DESeq2)",
                         "Sex (Mouse LFCE)", "Sex (Mouse P DESeq2)")


#### ALDEx2 Phylum results ####
ps6.ic.nm.phy.sd<-sample_data(ps6.ic.nm.phy)

covariates.ps6.ic.nm.phy <- data.frame("colony" = recode(ps6.ic.nm.phy.sd$colony,Elizabeth = 1, Fenty = 2, Ichabod = 3, Lucy = 4, Macbeth = 5, Xena = 6),
                                       "subcaste" = recode(ps6.ic.nm.phy.sd$subcaste,queen = 1, breeding_male = 2, disperser = 3, worker = 4, soldier = 5),
                                       "weight" = ps6.ic.nm.phy.sd$weight,
                                       "age" = ps6.ic.nm.phy.sd$age,
                                       "rank" = ps6.ic.nm.phy.sd$rank,
                                       "sex" = ps6.ic.nm.phy.sd$sex)
mm.ps6.ic.nm.phy <- model.matrix(~ colony + subcaste + weight + age + rank + sex, covariates.ps6.ic.nm.phy)
a2.ps6.ic.nm.phy <- aldex.clr(as.data.frame(t(otu_table(ps6.ic.nm.phy))), mm.ps6.ic.nm.phy, mc.samples=128, denom="all", verbose=F)
a2.ps6.ic.nm.phy.glm.test <- aldex.glm(a2.ps6.ic.nm.phy, mm.ps6.ic.nm.phy)
a2.ps6.ic.nm.phy.glm.test$Phylum<-rownames(a2.ps6.ic.nm.phy.glm.test)

ps6.ic.phy.sd<-sample_data(ps6.ic.phy)
a2.ps6.ic.phy.spe<-aldex(as.data.frame(t(otu_table(ps6.ic.phy))), ps6.ic.phy.sd$spe, mc.samples=128, test="t", effect=TRUE,
                         include.sample.summary=FALSE, denom="all", verbose=FALSE)
a2.ps6.ic.phy.spe$Phylum<-rownames(a2.ps6.ic.phy.spe)

ps6.mouse.phy.sd<-sample_data(ps6.mouse.phy)
a2.ps6.mouse.phy.sex<-aldex(as.data.frame(t(otu_table(ps6.mouse.phy))), ps6.mouse.phy.sd$sex, mc.samples=128, test="t", effect=TRUE,
                            include.sample.summary=FALSE, denom="all", verbose=FALSE)
a2.ps6.mouse.phy.sex$Phylum<-rownames(a2.ps6.mouse.phy.sex)

aldex.res.phy.total1<-merge(a2.ps6.ic.nm.phy.glm.test[,c(36,30,31,25,35,13,32,17,33,21,34)],a2.ps6.ic.phy.spe[,c(12,6,11)],by="Phylum",all=T)
aldex.res.phy.total<-merge(aldex.res.phy.total1,a2.ps6.mouse.phy.sex[,c(12,6,11)],by="Phylum",all=T)

colnames(aldex.res.phy.total)<-c("Phylum","Colony (P ALDEx2)",
                                 "Social Phenotype (P ALDEx2)","Sex (Beta)", "Sex (P ALDEx2)",
                                 "Weight (Effect)","Weight (P ALDEx2)","Age (Effect)","Age (P ALDEx2)","Rank (Effect)","Rank (P ALDEx2)",
                                 "Species (Effect)", "Species (P ALDEx2)",
                                 "Sex (Mouse Effect)", "Sex (Mouse P ALDEx2)")

#### ANCOM BC Phylum results #####
library(ANCOMBC)
ancom.phy.colony = ancombc(phyloseq = ps6.ic.nm.phy, formula = "colony + sex + subcaste + weight + age + rank", 
                           p_adj_method = "fdr", zero_cut = 1.1, 
                           group = "colony", tol = 1e-5, 
                           max_iter = 100, conserve = TRUE, alpha = 0.05, global = TRUE)
ancom.phy.colony.res_global = ancom.phy.colony$res_global
ancom.phy.colony.res_global$Phylum<-rownames(ancom.phy.colony.res_global)

ancom.phy.subcaste = ancombc(phyloseq = ps6.ic.nm.phy, formula = "colony + sex + subcaste + weight + age + rank", 
                             p_adj_method = "fdr", zero_cut = 1.1, 
                             group = "subcaste", tol = 1e-5, 
                             max_iter = 100, conserve = TRUE, alpha = 0.05, global = TRUE)
ancom.phy.subcaste.res_global = ancom.phy.subcaste$res_global
ancom.phy.subcaste.res_global$Phylum<-rownames(ancom.phy.subcaste.res_global)

ancom.phy.sex = ancombc(phyloseq = ps6.ic.nm.phy, formula = "colony + sex + subcaste + weight + age +rank", 
                        p_adj_method = "fdr", zero_cut = 1.1, 
                        group = "sex", tol = 1e-5, 
                        max_iter = 100, conserve = TRUE, alpha = 0.05, global = FALSE)
res.ancom.phy.sex = ancom.phy.sex$res
res.ancom.phy.sex.tab = cbind(res.ancom.phy.sex$beta,res.ancom.phy.sex$q_val)
res.ancom.phy.sex.tab$Phylum<-rownames(res.ancom.phy.sex.tab)

ancom.phy.spe = ancombc(phyloseq = ps6.ic.phy, formula = "spe", 
                        p_adj_method = "fdr", zero_cut = 1.1, 
                        group = "spe", tol = 1e-5, 
                        max_iter = 100, conserve = TRUE, alpha = 0.05, global = FALSE)
res.ancom.phy.spe = ancom.phy.spe$res
res.ancom.phy.spe.tab<- cbind(res.ancom.phy.spe$beta,res.ancom.phy.spe$q_val)
res.ancom.phy.spe.tab$Phylum<-rownames(res.ancom.phy.spe.tab)

ancom.phy.mouse.sex = ancombc(phyloseq = ps6.mouse.phy, formula = "sex", 
                              p_adj_method = "fdr", zero_cut = 1.1, 
                              group = "sex", tol = 1e-5, 
                              max_iter = 100, conserve = TRUE, alpha = 0.05, global = FALSE)
res.ancom.phy.mouse.sex = ancom.phy.mouse.sex$res
res.ancom.phy.mouse.sex.tab<- cbind(res.ancom.phy.mouse.sex$beta,res.ancom.phy.mouse.sex$q_val)
res.ancom.phy.mouse.sex.tab$Phylum<-rownames(res.ancom.phy.mouse.sex.tab)

ancom.res.phy.tot3<-merge(ancom.phy.colony.res_global[,c(5,3)],ancom.phy.subcaste.res_global[,c(5,3)],by="Phylum",all=T)
ancom.res.phy.tot2<-merge(ancom.res.tot3,res.ancom.phy.sex.tab[,c(27,6,19,11,24,12,25,13,26)],by="Phylum",all=T)
ancom.res.phy.tot1<-merge(ancom.res.tot2,res.ancom.phy.spe.tab[,c(3,1,2)],by="Phylum",all=T)
ancom.res.phy.tot<-merge(ancom.res.tot1,res.ancom.phy.mouse.sex.tab[,c(3,1,2)],by="Phylum",all=T)

colnames(ancom.res.phy.tot)<-c("Phylum","Colony (P ANCOMBC)",
                               "Social Phenotype (P ANCOMBC)","Sex (Beta)", "Sex (P ANCOMBC)",
                               "Weight (Beta)","Weight (P adj ANCOMBC)","Age (Beta)","Age (P ANCOMBC)","Rank (Beta)","Rank (P ANCOMBC)",
                               "Species (Beta)", "Species (P ANCOMBC)",
                               "Sex (Mouse Beta)", "Sex (Mouse P ANCOMBC)")

phy.res.total1<-merge(res.phy.tot,aldex.res.phy.total,by="Phylum",all=T)
phy.res.total<-merge(phy.res.total1,ancom.res.phy.tot,by="Phylum",all=T)

### Class Differential abundance result ####
dds.cla.nm <-phyloseq_to_deseq2(ps6.ic.nm.cla, ~ colony + sex + subcaste) # create full model without interactions
dds.cla.nm = estimateSizeFactors(dds.cla.nm, geoMeans = apply(counts(dds.cla.nm), 1, gm_mean))

dds.cla.colony.pval<-DESeq(dds.cla.nm,test="LRT",reduced= ~ sex + subcaste) # perform LRT to obtain p value #
res.dds.cla.colony.pval = cbind(as(results(dds.cla.colony.pval), "data.frame"), as(tax_table(ps6.ic.nm.cla)[rownames(dds.cla.colony.pval), ], "matrix"))
dds.cla.subcaste.pval<-DESeq(dds.cla.nm,test="LRT",reduced= ~ sex + colony) # perform LRT to obtain p value #
res.dds.cla.subcaste.pval = cbind(as(results(dds.cla.subcaste.pval), "data.frame"), as(tax_table(ps6.ic.nm.cla)[rownames(dds.cla.subcaste.pval), ], "matrix"))
dds.cla.sex.pval<-DESeq(dds.cla.nm,test="LRT",reduced= ~ subcaste + colony) # perform LRT to obtain p value #
dds.cla.sex.lfce<-DESeq(dds.cla.nm,test="Wald",fitType="parametric") # perform Wald test to obtain lfce #
res.dds.cla.sex.pval = cbind(as(results(dds.cla.sex.pval), "data.frame"), as(tax_table(ps6.ic.nm.cla)[rownames(dds.cla.sex.pval), ], "matrix"))
res.dds.cla.sex.lfce = as(results(dds.cla.sex.lfce,contrast=c("sex","male","female")),'data.frame')
res.dds.cla.sex.lfce$Phylum<-rownames(res.dds.cla.sex.lfce)

dds.cla.spe.ic <-phyloseq_to_deseq2(ps6.ic.cla, ~ spe) # create full model without interactions
dds.cla.spe.ic = estimateSizeFactors(dds.cla.spe.ic, geoMeans = apply(counts(dds.cla.spe.ic), 1, gm_mean))
dds.cla.spe.ic.pval<-DESeq(dds.cla.spe.ic,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
dds.cla.spe.lfce<-DESeq(dds.cla.spe.ic,test="Wald",fitType="parametric")
res.dds.cla.spe.pval = cbind(as(results(dds.cla.spe.ic.pval), "data.frame"), as(tax_table(ps6.ic.cla)[rownames(dds.cla.spe.ic.pval), ], "matrix"))
res.dds.cla.spe.lfce = as(results(dds.cla.spe.lfce,contrast=c("spe","nmr","mouse")),'data.frame')
res.dds.cla.spe.lfce$Class<-rownames(res.dds.cla.spe.lfce)

dds.cla.2 <-phyloseq_to_deseq2(ps6.ic.2.cla, ~ colony + sex + subcaste + colony:subcaste + sex:colony + sex:subcaste) # create full model 
dds.cla.2 = estimateSizeFactors(dds.cla.2, geoMeans = apply(counts(dds.cla.2), 1, gm_mean))
dds.cla.subcaste.colony.pval<-DESeq(dds.cla.2,test="LRT",reduced= ~ colony + sex + subcaste + sex:colony + sex:subcaste) # perform LRT to obtain p value #
res.dds.cla.subcaste.colony.pval = cbind(as(results(dds.cla.subcaste.colony.pval), "data.frame"), as(tax_table(ps6.ic.2.cla)[rownames(dds.cla.subcaste.colony.pval), ], "matrix"))
dds.cla.colony.sex.pval<-DESeq(dds.cla.2,test="LRT",reduced= ~ colony + sex + subcaste + colony:subcaste + sex:subcaste) # perform LRT to obtain p value #
res.dds.cla.colony.sex.pval = cbind(as(results(dds.cla.colony.sex.pval), "data.frame"), as(tax_table(ps6.ic.2.cla)[rownames(dds.cla.subcaste.colony.pval), ], "matrix"))
dds.cla.subcaste.sex.pval<-DESeq(dds.cla.2,test="LRT",reduced= ~ colony + sex + subcaste + colony:subcaste + sex:colony) # perform LRT to obtain p value #
res.dds.cla.subcaste.sex.pval = cbind(as(results(dds.cla.subcaste.sex.pval), "data.frame"), as(tax_table(ps6.ic.2.cla)[rownames(dds.cla.subcaste.colony.pval), ], "matrix"))

dds.cla.mouse <-phyloseq_to_deseq2(ps6.mouse.cla, ~ sex) # create full model 
dds.cla.mouse = estimateSizeFactors(dds.cla.mouse, geoMeans = apply(counts(dds.cla.mouse), 1, gm_mean))
dds.cla.mouse.sex.pval<-DESeq(dds.cla.mouse,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
dds.cla.mouse.sex.lfce<-DESeq(dds.cla.mouse,test="Wald",fitType="parametric") # perform Wald test to obtain lfce #
res.dds.cla.mouse.sex.pval = cbind(as(results(dds.cla.mouse.sex.pval), "data.frame"), as(tax_table(ps6.mouse.cla)[rownames(dds.cla.mouse.sex.pval), ], "matrix"))
res.dds.cla.mouse.sex.lfce = as(results(dds.cla.mouse.sex.lfce,contrast=c("sex","male","female")),'data.frame')
res.dds.cla.mouse.sex.lfce$Phylum<-rownames(res.dds.cla.mouse.sex.lfce)

# combine results:
# Colony (p), Subcaste (p), Sex (p,lfce), Subcaste:Colony (p), Colony:Sex (p), 
# Subcaste:Sex(p), Species (p, lfce), SexMouse (p,lfce)

res.cla.ic<-cbind(as(tax_table(ps6.ic.nm.cla)[rownames(dds.cla.nm), ], "matrix"),
                  res.dds.cla.colony.pval[,6],
                  res.dds.cla.subcaste.pval[,6],
                  res.dds.cla.sex.lfce[,c(2,3)],
                  res.dds.cla.sex.pval[,6],
                  res.dds.cla.subcaste.colony.pval[,6],
                  res.dds.cla.colony.sex.pval[,6],
                  res.dds.cla.subcaste.sex.pval[,6])

res.cla.spe<-res.dds.cla.spe.pval[,c(8,9,2,3,6)]
res.cla.mousesex<-res.dds.cla.mouse.sex.pval[,c(8,9,2,3,6)]

res.cla.tot1<-merge(res.cla.ic,res.cla.spe,by="Class",all=T)
res.cla.tot2<-merge(res.cla.tot1,res.cla.mousesex,by="Class",all=T)

# add relative abundance of taxa in entire IC dataset #
cla.ra = transform_sample_counts(ps6.ic.cla, rel.abund)
cla.ra <-cbind(as(sample_data(cla.ra),'data.frame'),as.data.frame(otu_table(cla.ra))) # data frame of phyla abundance and sample data
df1.cla.ra <- cla.ra[,-c(1:13)] %>% summarise_all(funs(mean))
mdf1.cla.ra <- melt(df1.cla.ra)
colnames(mdf1.cla.ra)<-c("Class","rel.abund")
res.cla.tot<-merge(mdf1.cla.ra,res.cla.tot2,by="Class",all=T)
colnames(res.cla.tot)<-c("Class","Relative Abundance","Domain","Phylum","Order","Family","Genus","Colony (P adj)",
                         "Social Group (P adj)","Sex (LFCE)", "Sex (LFCSE)", "Sex (P adj)",
                         "Social Group X Colony (P adj)","Sex X Colony (P adj)","Sex X Social Group (P adj)",
                         "Species (LFCE)", "Species (LFCSE)", "Species (P adj)",
                         "Sex (Mouse LFCE)", "Sex (Mouse LFCSE)", "Sex (Mouse P adj)")

### Order Differential abundance result ####
dds.ord.nm <-phyloseq_to_deseq2(ps6.ic.nm.ord, ~ colony + sex + subcaste) # create full model without interactions
dds.ord.nm = estimateSizeFactors(dds.ord.nm, geoMeans = apply(counts(dds.ord.nm), 1, gm_mean))

dds.ord.colony.pval<-DESeq(dds.ord.nm,test="LRT",reduced= ~ sex + subcaste) # perform LRT to obtain p value #
res.dds.ord.colony.pval = cbind(as(results(dds.ord.colony.pval), "data.frame"), as(tax_table(ps6.ic.nm.ord)[rownames(dds.ord.colony.pval), ], "matrix"))
dds.ord.subcaste.pval<-DESeq(dds.ord.nm,test="LRT",reduced= ~ sex + colony) # perform LRT to obtain p value #
res.dds.ord.subcaste.pval = cbind(as(results(dds.ord.subcaste.pval), "data.frame"), as(tax_table(ps6.ic.nm.ord)[rownames(dds.ord.subcaste.pval), ], "matrix"))
dds.ord.sex.pval<-DESeq(dds.ord.nm,test="LRT",reduced= ~ subcaste + colony) # perform LRT to obtain p value #
dds.ord.sex.lfce<-DESeq(dds.ord.nm,test="Wald",fitType="parametric") # perform Wald test to obtain lfce #
res.dds.ord.sex.pval = cbind(as(results(dds.ord.sex.pval), "data.frame"), as(tax_table(ps6.ic.nm.ord)[rownames(dds.ord.sex.pval), ], "matrix"))
res.dds.ord.sex.lfce = as(results(dds.ord.sex.lfce,contrast=c("sex","male","female")),'data.frame')
res.dds.ord.sex.lfce$Phylum<-rownames(res.dds.ord.sex.lfce)

dds.ord.spe.ic <-phyloseq_to_deseq2(ps6.ic.ord, ~ spe) # create full model without interactions
dds.ord.spe.ic = estimateSizeFactors(dds.ord.spe.ic, geoMeans = apply(counts(dds.ord.spe.ic), 1, gm_mean))
dds.ord.spe.ic.pval<-DESeq(dds.ord.spe.ic,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
dds.ord.spe.lfce<-DESeq(dds.ord.spe.ic,test="Wald",fitType="parametric")
res.dds.ord.spe.pval = cbind(as(results(dds.ord.spe.ic.pval), "data.frame"), as(tax_table(ps6.ic.ord)[rownames(dds.ord.spe.ic.pval), ], "matrix"))
res.dds.ord.spe.lfce = as(results(dds.ord.spe.lfce,contrast=c("spe","nmr","mouse")),'data.frame')
res.dds.ord.spe.lfce$Order<-rownames(res.dds.ord.spe.lfce)

dds.ord.2 <-phyloseq_to_deseq2(ps6.ic.2.ord, ~ colony + sex + subcaste + colony:subcaste + sex:colony + sex:subcaste) # create full model 
dds.ord.2 = estimateSizeFactors(dds.ord.2, geoMeans = apply(counts(dds.ord.2), 1, gm_mean))
dds.ord.subcaste.colony.pval<-DESeq(dds.ord.2,test="LRT",reduced= ~ colony + sex + subcaste + sex:colony + sex:subcaste) # perform LRT to obtain p value #
res.dds.ord.subcaste.colony.pval = cbind(as(results(dds.ord.subcaste.colony.pval), "data.frame"), as(tax_table(ps6.ic.2.ord)[rownames(dds.ord.subcaste.colony.pval), ], "matrix"))
dds.ord.colony.sex.pval<-DESeq(dds.ord.2,test="LRT",reduced= ~ colony + sex + subcaste + colony:subcaste + sex:subcaste) # perform LRT to obtain p value #
res.dds.ord.colony.sex.pval = cbind(as(results(dds.ord.colony.sex.pval), "data.frame"), as(tax_table(ps6.ic.2.ord)[rownames(dds.ord.subcaste.colony.pval), ], "matrix"))
dds.ord.subcaste.sex.pval<-DESeq(dds.ord.2,test="LRT",reduced= ~ colony + sex + subcaste + colony:subcaste + sex:colony) # perform LRT to obtain p value #
res.dds.ord.subcaste.sex.pval = cbind(as(results(dds.ord.subcaste.sex.pval), "data.frame"), as(tax_table(ps6.ic.2.ord)[rownames(dds.ord.subcaste.colony.pval), ], "matrix"))

dds.ord.mouse <-phyloseq_to_deseq2(ps6.mouse.ord, ~ sex) # create full model 
dds.ord.mouse = estimateSizeFactors(dds.ord.mouse, geoMeans = apply(counts(dds.ord.mouse), 1, gm_mean))
dds.ord.mouse.sex.pval<-DESeq(dds.ord.mouse,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
dds.ord.mouse.sex.lfce<-DESeq(dds.ord.mouse,test="Wald",fitType="parametric") # perform Wald test to obtain lfce #
res.dds.ord.mouse.sex.pval = cbind(as(results(dds.ord.mouse.sex.pval), "data.frame"), as(tax_table(ps6.mouse.ord)[rownames(dds.ord.mouse.sex.pval), ], "matrix"))
res.dds.ord.mouse.sex.lfce = as(results(dds.ord.mouse.sex.lfce,contrast=c("sex","male","female")),'data.frame')
res.dds.ord.mouse.sex.lfce$Phylum<-rownames(res.dds.ord.mouse.sex.lfce)

# combine results:
# Colony (p), Subcaste (p), Sex (p,lfce), Subcaste:Colony (p), Colony:Sex (p), 
# Subcaste:Sex(p), Species (p, lfce), SexMouse (p,lfce)

res.ord.ic<-cbind(as(tax_table(ps6.ic.nm.ord)[rownames(dds.ord.nm), ], "matrix"),
                  res.dds.ord.colony.pval[,6],
                  res.dds.ord.subcaste.pval[,6],
                  res.dds.ord.sex.lfce[,c(2,3)],
                  res.dds.ord.sex.pval[,6],
                  res.dds.ord.subcaste.colony.pval[,6],
                  res.dds.ord.colony.sex.pval[,6],
                  res.dds.ord.subcaste.sex.pval[,6])

res.ord.spe<-res.dds.ord.spe.pval[,c(10,2,3,6)]
res.ord.mousesex<-res.dds.ord.mouse.sex.pval[,c(10,2,3,6)]

res.ord.tot1<-merge(res.ord.ic,res.ord.spe,by="Order",all=T)
res.ord.tot2<-merge(res.ord.tot1,res.ord.mousesex,by="Order",all=T)

# add relative abundance of taxa in entire IC dataset #
ord.ra = transform_sample_counts(ps6.ic.ord, rel.abund)
ord.ra <-cbind(as(sample_data(ord.ra),'data.frame'),as.data.frame(otu_table(ord.ra))) # data frame of phyla abundance and sample data
df1.ord.ra <- ord.ra[,-c(1:13)] %>% summarise_all(funs(mean))
mdf1.ord.ra <- melt(df1.ord.ra)
colnames(mdf1.ord.ra)<-c("Order","rel.abund")
res.ord.tot<-merge(mdf1.ord.ra,res.ord.tot2,by="Order",all=T)
colnames(res.ord.tot)<-c("Order","Relative Abundance","Domain","Phylum","Class","Family","Genus","Colony (P adj)",
                         "Social Group (P adj)","Sex (LFCE)", "Sex (LFCSE)", "Sex (P adj)",
                         "Social Group X Colony (P adj)","Sex X Colony (P adj)","Sex X Social Group (P adj)",
                         "Species (LFCE)", "Species (LFCSE)", "Species (P adj)",
                         "Sex (Mouse LFCE)", "Sex (Mouse LFCSE)", "Sex (Mouse P adj)")


### Family Differential abundance result ####
dds.fam.nm <-phyloseq_to_deseq2(ps6.ic.nm.fam, ~ colony + sex + subcaste) # create full model without interactions
dds.fam.nm = estimateSizeFactors(dds.fam.nm, geoMeans = apply(counts(dds.fam.nm), 1, gm_mean))

dds.fam.colony.pval<-DESeq(dds.fam.nm,test="LRT",reduced= ~ sex + subcaste) # perform LRT to obtain p value #
res.dds.fam.colony.pval = cbind(as(results(dds.fam.colony.pval), "data.frame"), as(tax_table(ps6.ic.nm.fam)[rownames(dds.fam.colony.pval), ], "matrix"))
dds.fam.subcaste.pval<-DESeq(dds.fam.nm,test="LRT",reduced= ~ sex + colony) # perform LRT to obtain p value #
res.dds.fam.subcaste.pval = cbind(as(results(dds.fam.subcaste.pval), "data.frame"), as(tax_table(ps6.ic.nm.fam)[rownames(dds.fam.subcaste.pval), ], "matrix"))
dds.fam.sex.pval<-DESeq(dds.fam.nm,test="LRT",reduced= ~ subcaste + colony) # perform LRT to obtain p value #
dds.fam.sex.lfce<-DESeq(dds.fam.nm,test="Wald",fitType="parametric") # perform Wald test to obtain lfce #
res.dds.fam.sex.pval = cbind(as(results(dds.fam.sex.pval), "data.frame"), as(tax_table(ps6.ic.nm.fam)[rownames(dds.fam.sex.pval), ], "matrix"))
res.dds.fam.sex.lfce = as(results(dds.fam.sex.lfce,contrast=c("sex","male","female")),'data.frame')
res.dds.fam.sex.lfce$Phylum<-rownames(res.dds.fam.sex.lfce)

dds.fam.spe.ic <-phyloseq_to_deseq2(ps6.ic.fam, ~ spe) # create full model without interactions
dds.fam.spe.ic = estimateSizeFactors(dds.fam.spe.ic, geoMeans = apply(counts(dds.fam.spe.ic), 1, gm_mean))
dds.fam.spe.ic.pval<-DESeq(dds.fam.spe.ic,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
dds.fam.spe.lfce<-DESeq(dds.fam.spe.ic,test="Wald",fitType="parametric")
res.dds.fam.spe.pval = cbind(as(results(dds.fam.spe.ic.pval), "data.frame"), as(tax_table(ps6.ic.fam)[rownames(dds.fam.spe.ic.pval), ], "matrix"))
res.dds.fam.spe.lfce = as(results(dds.fam.spe.lfce,contrast=c("spe","nmr","mouse")),'data.frame')
res.dds.fam.spe.lfce$Family<-rownames(res.dds.fam.spe.lfce)

dds.fam.2 <-phyloseq_to_deseq2(ps6.ic.2.fam, ~ colony + sex + subcaste + colony:subcaste + sex:colony + sex:subcaste) # create full model 
dds.fam.2 = estimateSizeFactors(dds.fam.2, geoMeans = apply(counts(dds.fam.2), 1, gm_mean))
dds.fam.subcaste.colony.pval<-DESeq(dds.fam.2,test="LRT",reduced= ~ colony + sex + subcaste + sex:colony + sex:subcaste) # perform LRT to obtain p value #
res.dds.fam.subcaste.colony.pval = cbind(as(results(dds.fam.subcaste.colony.pval), "data.frame"), as(tax_table(ps6.ic.2.fam)[rownames(dds.fam.subcaste.colony.pval), ], "matrix"))
dds.fam.colony.sex.pval<-DESeq(dds.fam.2,test="LRT",reduced= ~ colony + sex + subcaste + colony:subcaste + sex:subcaste) # perform LRT to obtain p value #
res.dds.fam.colony.sex.pval = cbind(as(results(dds.fam.colony.sex.pval), "data.frame"), as(tax_table(ps6.ic.2.fam)[rownames(dds.fam.subcaste.colony.pval), ], "matrix"))
dds.fam.subcaste.sex.pval<-DESeq(dds.fam.2,test="LRT",reduced= ~ colony + sex + subcaste + colony:subcaste + sex:colony) # perform LRT to obtain p value #
res.dds.fam.subcaste.sex.pval = cbind(as(results(dds.fam.subcaste.sex.pval), "data.frame"), as(tax_table(ps6.ic.2.fam)[rownames(dds.fam.subcaste.colony.pval), ], "matrix"))

dds.fam.mouse <-phyloseq_to_deseq2(ps6.mouse.fam, ~ sex) # create full model 
dds.fam.mouse = estimateSizeFactors(dds.fam.mouse, geoMeans = apply(counts(dds.fam.mouse), 1, gm_mean))
dds.fam.mouse.sex.pval<-DESeq(dds.fam.mouse,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
dds.fam.mouse.sex.lfce<-DESeq(dds.fam.mouse,test="Wald",fitType="parametric") # perform Wald test to obtain lfce #
res.dds.fam.mouse.sex.pval = cbind(as(results(dds.fam.mouse.sex.pval), "data.frame"), as(tax_table(ps6.mouse.fam)[rownames(dds.fam.mouse.sex.pval), ], "matrix"))
res.dds.fam.mouse.sex.lfce = as(results(dds.fam.mouse.sex.lfce,contrast=c("sex","male","female")),'data.frame')
res.dds.fam.mouse.sex.lfce$Phylum<-rownames(res.dds.fam.mouse.sex.lfce)

# combine results:
# Colony (p), Subcaste (p), Sex (p,lfce), Subcaste:Colony (p), Colony:Sex (p), 
# Subcaste:Sex(p), Species (p, lfce), SexMouse (p,lfce)

res.fam.ic<-cbind(as(tax_table(ps6.ic.nm.fam)[rownames(dds.fam.nm), ], "matrix"),
                  res.dds.fam.colony.pval[,6],
                  res.dds.fam.subcaste.pval[,6],
                  res.dds.fam.sex.lfce[,c(2,3)],
                  res.dds.fam.sex.pval[,6],
                  res.dds.fam.subcaste.colony.pval[,6],
                  res.dds.fam.colony.sex.pval[,6],
                  res.dds.fam.subcaste.sex.pval[,6])

res.fam.spe<-res.dds.fam.spe.pval[,c(11,2,3,6)]
res.fam.mousesex<-res.dds.fam.mouse.sex.pval[,c(11,2,3,6)]

res.fam.tot1<-merge(res.fam.ic,res.fam.spe,by="Family",all=T)
res.fam.tot2<-merge(res.fam.tot1,res.fam.mousesex,by="Family",all=T)

# add relative abundance of taxa in entire IC dataset #
fam.ra = transform_sample_counts(ps6.ic.fam, rel.abund)
fam.ra <-cbind(as(sample_data(fam.ra),'data.frame'),as.data.frame(otu_table(fam.ra))) # data frame of phyla abundance and sample data
df1.fam.ra <- fam.ra[,-c(1:15)] %>% summarise_all(funs(mean))
mdf1.fam.ra <- melt(df1.fam.ra)
colnames(mdf1.fam.ra)<-c("Family","rel.abund")
res.fam.tot<-merge(mdf1.fam.ra,res.fam.tot2,by="Family",all=T)
colnames(res.fam.tot)<-c("Family","Relative Abundance","Domain","Phylum","Class","Order","Genus","Colony (P adj)",
                         "Social Group (P adj)","Sex (LFCE)", "Sex (LFCSE)", "Sex (P adj)",
                         "Social Group X Colony (P adj)","Sex X Colony (P adj)","Sex X Social Group (P adj)",
                         "Species (LFCE)", "Species (LFCSE)", "Species (P adj)",
                         "Sex (Mouse LFCE)", "Sex (Mouse LFCSE)", "Sex (Mouse P adj)")

### Genus Differential abundance result ####
dds.gen.nm <-phyloseq_to_deseq2(ps6.ic.nm.gen, ~ colony + sex + subcaste) # create full model without interactions
dds.gen.nm = estimateSizeFactors(dds.gen.nm, geoMeans = apply(counts(dds.gen.nm), 1, gm_mean))

dds.gen.colony.pval<-DESeq(dds.gen.nm,test="LRT",reduced= ~ sex + subcaste) # perform LRT to obtain p value #
res.dds.gen.colony.pval = cbind(as(results(dds.gen.colony.pval), "data.frame"), as(tax_table(ps6.ic.nm.gen)[rownames(dds.gen.colony.pval), ], "matrix"))
dds.gen.subcaste.pval<-DESeq(dds.gen.nm,test="LRT",reduced= ~ sex + colony) # perform LRT to obtain p value #
res.dds.gen.subcaste.pval = cbind(as(results(dds.gen.subcaste.pval), "data.frame"), as(tax_table(ps6.ic.nm.gen)[rownames(dds.gen.subcaste.pval), ], "matrix"))
dds.gen.sex.pval<-DESeq(dds.gen.nm,test="LRT",reduced= ~ subcaste + colony) # perform LRT to obtain p value #
dds.gen.sex.lfce<-DESeq(dds.gen.nm,test="Wald",fitType="parametric") # perform Wald test to obtain lfce #
res.dds.gen.sex.pval = cbind(as(results(dds.gen.sex.pval), "data.frame"), as(tax_table(ps6.ic.nm.gen)[rownames(dds.gen.sex.pval), ], "matrix"))
res.dds.gen.sex.lfce = as(results(dds.gen.sex.lfce,contrast=c("sex","male","female")),'data.frame')
res.dds.gen.sex.lfce$Phylum<-rownames(res.dds.gen.sex.lfce)

dds.gen.spe.ic <-phyloseq_to_deseq2(ps6.ic.gen, ~ spe) # create full model without interactions
dds.gen.spe.ic = estimateSizeFactors(dds.gen.spe.ic, geoMeans = apply(counts(dds.gen.spe.ic), 1, gm_mean))
dds.gen.spe.ic.pval<-DESeq(dds.gen.spe.ic,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
dds.gen.spe.lfce<-DESeq(dds.gen.spe.ic,test="Wald",fitType="parametric")
res.dds.gen.spe.pval = cbind(as(results(dds.gen.spe.ic.pval), "data.frame"), as(tax_table(ps6.ic.gen)[rownames(dds.gen.spe.ic.pval), ], "matrix"))
res.dds.gen.spe.lfce = as(results(dds.gen.spe.lfce,contrast=c("spe","nmr","mouse")),'data.frame')
res.dds.gen.spe.lfce$Genus<-rownames(res.dds.gen.spe.lfce)

dds.gen.2 <-phyloseq_to_deseq2(ps6.ic.2.gen, ~ colony + sex + subcaste + colony:subcaste + sex:colony + sex:subcaste) # create full model 
dds.gen.2 = estimateSizeFactors(dds.gen.2, geoMeans = apply(counts(dds.gen.2), 1, gm_mean))
dds.gen.subcaste.colony.pval<-DESeq(dds.gen.2,test="LRT",reduced= ~ colony + sex + subcaste + sex:colony + sex:subcaste) # perform LRT to obtain p value #
res.dds.gen.subcaste.colony.pval = cbind(as(results(dds.gen.subcaste.colony.pval), "data.frame"), as(tax_table(ps6.ic.2.gen)[rownames(dds.gen.subcaste.colony.pval), ], "matrix"))
dds.gen.colony.sex.pval<-DESeq(dds.gen.2,test="LRT",reduced= ~ colony + sex + subcaste + colony:subcaste + sex:subcaste) # perform LRT to obtain p value #
res.dds.gen.colony.sex.pval = cbind(as(results(dds.gen.colony.sex.pval), "data.frame"), as(tax_table(ps6.ic.2.gen)[rownames(dds.gen.subcaste.colony.pval), ], "matrix"))
dds.gen.subcaste.sex.pval<-DESeq(dds.gen.2,test="LRT",reduced= ~ colony + sex + subcaste + colony:subcaste + sex:colony) # perform LRT to obtain p value #
res.dds.gen.subcaste.sex.pval = cbind(as(results(dds.gen.subcaste.sex.pval), "data.frame"), as(tax_table(ps6.ic.2.gen)[rownames(dds.gen.subcaste.colony.pval), ], "matrix"))

dds.gen.mouse <-phyloseq_to_deseq2(ps6.mouse.gen, ~ sex) # create full model 
dds.gen.mouse = estimateSizeFactors(dds.gen.mouse, geoMeans = apply(counts(dds.gen.mouse), 1, gm_mean))
dds.gen.mouse.sex.pval<-DESeq(dds.gen.mouse,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
dds.gen.mouse.sex.lfce<-DESeq(dds.gen.mouse,test="Wald",fitType="parametric") # perform Wald test to obtain lfce #
res.dds.gen.mouse.sex.pval = cbind(as(results(dds.gen.mouse.sex.pval), "data.frame"), as(tax_table(ps6.mouse.gen)[rownames(dds.gen.mouse.sex.pval), ], "matrix"))
res.dds.gen.mouse.sex.lfce = as(results(dds.gen.mouse.sex.lfce,contrast=c("sex","male","female")),'data.frame')
res.dds.gen.mouse.sex.lfce$Phylum<-rownames(res.dds.gen.mouse.sex.lfce)

# combine results:
# Colony (p), Subcaste (p), Sex (p,lfce), Subcaste:Colony (p), Colony:Sex (p), 
# Subcaste:Sex(p), Species (p, lfce), SexMouse (p,lfce)

res.gen.ic<-cbind(as(tax_table(ps6.ic.nm.gen)[rownames(dds.gen.nm), ], "matrix"),
                  res.dds.gen.colony.pval[,6],
                  res.dds.gen.subcaste.pval[,6],
                  res.dds.gen.sex.lfce[,c(2,3)],
                  res.dds.gen.sex.pval[,6],
                  res.dds.gen.subcaste.colony.pval[,6],
                  res.dds.gen.colony.sex.pval[,6],
                  res.dds.gen.subcaste.sex.pval[,6])

res.gen.spe<-res.dds.gen.spe.pval[,c(12,2,3,6)]
res.gen.mousesex<-res.dds.gen.mouse.sex.pval[,c(12,2,3,6)]

res.gen.tot1<-merge(res.gen.ic,res.gen.spe,by="Genus",all=T)
res.gen.tot2<-merge(res.gen.tot1,res.gen.mousesex,by="Genus",all=T)

# add relative abundance of taxa in entire IC dataset #
gen.ra = transform_sample_counts(ps6.ic.gen, rel.abund)
gen.ra <-cbind(as(sample_data(gen.ra),'data.frame'),as.data.frame(otu_table(gen.ra))) # data frame of phyla abundance and sample data
df1.gen.ra <- gen.ra[,-c(1:13)] %>% summarise_all(funs(mean))
mdf1.gen.ra <- melt(df1.gen.ra)
colnames(mdf1.gen.ra)<-c("Genus","rel.abund")
res.gen.tot<-merge(mdf1.gen.ra,res.gen.tot2,by="Genus",all=T)
colnames(res.gen.tot)<-c("Genus","Relative Abundance","Domain","Phylum","Class","Order","Family","Colony (P adj)",
                         "Social Group (P adj)","Sex (LFCE)", "Sex (LFCSE)", "Sex (P adj)",
                         "Social Group X Colony (P adj)","Sex X Colony (P adj)","Sex X Social Group (P adj)",
                         "Species (LFCE)", "Species (LFCSE)", "Species (P adj)",
                         "Sex (Mouse LFCE)", "Sex (Mouse LFCSE)", "Sex (Mouse P adj)")



### ASV Differential abundance result ####
dds.nm <-phyloseq_to_deseq2(ps6.ic.nm, ~ colony + sex + subcaste) # create full model without interactions
dds.nm = estimateSizeFactors(dds.nm, geoMeans = apply(counts(dds.nm), 1, gm_mean))

dds.colony.pval<-DESeq(dds.nm,test="LRT",reduced= ~ sex + subcaste) # perform LRT to obtain p value #
res.dds.colony.pval = cbind(as(results(dds.colony.pval), "data.frame"), as(tax_table(ps6.ic.nm)[rownames(dds.colony.pval), ], "matrix"))
dds.subcaste.pval<-DESeq(dds.nm,test="LRT",reduced= ~ sex + colony) # perform LRT to obtain p value #
res.dds.subcaste.pval = cbind(as(results(dds.subcaste.pval), "data.frame"), as(tax_table(ps6.ic.nm)[rownames(dds.subcaste.pval), ], "matrix"))
dds.sex.pval<-DESeq(dds.nm,test="LRT",reduced= ~ subcaste + colony) # perform LRT to obtain p value #
dds.sex.lfce<-DESeq(dds.nm,test="Wald",fitType="parametric") # perform Wald test to obtain lfce #
res.dds.sex.pval = cbind(as(results(dds.sex.pval), "data.frame"), as(tax_table(ps6.ic.nm)[rownames(dds.sex.pval), ], "matrix"))
res.dds.sex.lfce = as(results(dds.sex.lfce,contrast=c("sex","male","female")),'data.frame')
res.dds.sex.lfce$ASV<-rownames(res.dds.sex.lfce)

dds.spe.ic <-phyloseq_to_deseq2(ps6.ic, ~ spe) # create full model without interactions
dds.spe.ic = estimateSizeFactors(dds.spe.ic, geoMeans = apply(counts(dds.spe.ic), 1, gm_mean))
dds.spe.ic.pval<-DESeq(dds.spe.ic,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
dds.spe.lfce<-DESeq(dds.spe.ic,test="Wald",fitType="parametric")
res.dds.spe.pval = cbind(as(results(dds.spe.ic.pval), "data.frame"), as(tax_table(ps6.ic)[rownames(dds.spe.ic.pval), ], "matrix"))
res.dds.spe.lfce = as(results(dds.spe.lfce,contrast=c("spe","nmr","mouse")),'data.frame')
res.dds.spe.lfce$ASV<-rownames(res.dds.spe.lfce)
res.dds.spe.pval$ASV<-rownames(res.dds.spe.pval)

dds.2 <-phyloseq_to_deseq2(ps6.ic.2, ~ colony + sex + subcaste + colony:subcaste + sex:colony + sex:subcaste) # create full model 
dds.2 = estimateSizeFactors(dds.2, geoMeans = apply(counts(dds.2), 1, gm_mean))
dds.subcaste.colony.pval<-DESeq(dds.2,test="LRT",reduced= ~ colony + sex + subcaste + sex:colony + sex:subcaste) # perform LRT to obtain p value #
res.dds.subcaste.colony.pval = cbind(as(results(dds.subcaste.colony.pval), "data.frame"), as(tax_table(ps6.ic.2)[rownames(dds.subcaste.colony.pval), ], "matrix"))
dds.colony.sex.pval<-DESeq(dds.2,test="LRT",reduced= ~ colony + sex + subcaste + colony:subcaste + sex:subcaste) # perform LRT to obtain p value #
res.dds.colony.sex.pval = cbind(as(results(dds.colony.sex.pval), "data.frame"), as(tax_table(ps6.ic.2)[rownames(dds.subcaste.colony.pval), ], "matrix"))
dds.subcaste.sex.pval<-DESeq(dds.2,test="LRT",reduced= ~ colony + sex + subcaste + colony:subcaste + sex:colony) # perform LRT to obtain p value #
res.dds.subcaste.sex.pval = cbind(as(results(dds.subcaste.sex.pval), "data.frame"), as(tax_table(ps6.ic.2)[rownames(dds.subcaste.colony.pval), ], "matrix"))

dds.mouse <-phyloseq_to_deseq2(ps6.mouse, ~ sex) # create full model 
dds.mouse = estimateSizeFactors(dds.mouse, geoMeans = apply(counts(dds.mouse), 1, gm_mean))
dds.mouse.sex.pval<-DESeq(dds.mouse,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
dds.mouse.sex.lfce<-DESeq(dds.mouse,test="Wald",fitType="parametric") # perform Wald test to obtain lfce #
res.dds.mouse.sex.pval = cbind(as(results(dds.mouse.sex.pval), "data.frame"), as(tax_table(ps6.mouse)[rownames(dds.mouse.sex.pval), ], "matrix"))
res.dds.mouse.sex.lfce = as(results(dds.mouse.sex.lfce,contrast=c("sex","male","female")),'data.frame')
res.dds.mouse.sex.lfce$ASV<-rownames(res.dds.mouse.sex.lfce)
res.dds.mouse.sex.pval$ASV<-rownames(res.dds.mouse.sex.pval)

# combine results:
# Colony (p), Subcaste (p), Sex (p,lfce), Subcaste:Colony (p), Colony:Sex (p), 
# Subcaste:Sex(p), Species (p, lfce), SexMouse (p,lfce)

res.ic<-cbind(as(tax_table(ps6.ic.nm)[rownames(dds.nm), ], "matrix"),
                  res.dds.colony.pval[,6],
                  res.dds.subcaste.pval[,6],
                  res.dds.sex.lfce[,c(2,3)],
                  res.dds.sex.pval[,6])
res.ic$ASV<-rownames(res.ic)

res.ic.2<-as.data.frame(cbind(as(tax_table(ps6.ic.2)[rownames(dds.2), ], "matrix"),
                  res.dds.subcaste.colony.pval[,6],
                  res.dds.colony.sex.pval[,6],
                  res.dds.subcaste.sex.pval[,6]))
res.ic.2$ASV<-rownames(res.ic.2)

res.ic.3<-as.data.frame(cbind(as(tax_table(ps6.ic)[rownames(dds.spe.ic), ], "matrix"),
                              res.dds.spe.pval[,c(13,2,3,6)]))
res.ic.3$ASV<-rownames(res.ic.3)

res.ic.4<-as.data.frame(cbind(as(tax_table(ps6.mouse)[rownames(dds.mouse), ], "matrix"),
                              res.dds.mouse.sex.pval[,c(13,2,3,6)]))
res.ic.4$ASV<-rownames(res.ic.4)


res.spe<-res.dds.spe.pval[,c(13,2,3,6)]
res.mousesex<-res.dds.mouse.sex.pval[,c(13,2,3,6)]

res.tot1<-merge(res.ic,res.ic.2,by="ASV",all=T)
res.tot2<-merge(res.tot1,res.spe,by="ASV",all=T)
res.tot3<-merge(res.tot2,res.mousesex,by="ASV",all=T)

# add relative abundance of taxa in entire IC dataset #
asv.ra = transform_sample_counts(ps6.ic, rel.abund)
asv.ra <-cbind(as(sample_data(asv.ra),'data.frame'),as.data.frame(otu_table(asv.ra))) # data frame of phyla abundance and sample data
df1.ra <- asv.ra[,-c(1:15)] %>% summarise_all(funs(mean))
mdf1.ra <- melt(df1.ra)
colnames(mdf1.ra)<-c("ASV","rel.abund")
res.tot<-merge(mdf1.ra,res.tot3,by="ASV",all=T)
res.tot<-res.tot[,-c(14:19)]
colnames(res.tot)<-c("ASV","Relative Abundance","Domain","Phylum","Class","Order","Family","Genus","Colony (P adj)",
                         "Social Group (P adj)","Sex (LFCE)", "Sex (LFCSE)", "Sex (P adj)",
                         "Social Group X Colony (P adj)","Sex X Colony (P adj)","Sex X Social Group (P adj)",
                         "Species (LFCE)", "Species (LFCSE)", "Species (P adj)",
                         "Sex (Mouse LFCE)", "Sex (Mouse LFCSE)", "Sex (Mouse P adj)")

res.asv.tax<-as.data.frame(as(tax_table(ps6.ic)[res.tot$ASV, ], "matrix"))

write.csv(res.asv.tax,"~Manuscript/deseq.asv.tax.csv")
write.csv(res.tot,"~Manuscript/deseq.asv.csv")
write.csv(res.gen.tot,"~Manuscript/deseq.gen.csv")
write.csv(res.fam.tot,"~Manuscript/deseq.fam.csv")
write.csv(res.ord.tot,"~Manuscript/deseq.ord.csv")
write.csv(res.cla.tot,"~Manuscript/deseq.cla.csv")
write.csv(res.phy.tot,"~Manuscript/deseq.phy.csv")

#### NMR versus mouse DA figure ####
p <- ggtree(phy_tree(ps6.ic.fam)) + geom_tiplab(size=3.5,align=T)
# get LFC into heatmap form
res.dds.fam.spe.lfce.hm<-as.data.frame(res.dds.fam.spe.lfce[,c(2)])
rownames(res.dds.fam.spe.lfce.hm)<-res.dds.fam.spe.lfce$Family

pdf(file="~Manuscript/Figures/fam.spe.DA.pdf",
    width=10,height=8,bg = "transparent")
gheatmap(p, res.dds.fam.spe.lfce.hm, offset = 1.6, width=0.5, font.size=3, 
         colnames_angle=-45, hjust=0,low = "#2b8cbe", high = "#e34a33")
dev.off()

# relative abundance in mouse and NMR 
fam.ra = transform_sample_counts(ps6.ic.fam, rel.abund)
fam.ra <-cbind(as(sample_data(fam.ra),'data.frame'),as.data.frame(otu_table(fam.ra))) # data frame of phyla abundance and sample data
df1.fam.ra <- fam.ra %>% group_by(spe) %>% summarise_all(funs(mean))
fam.ra.m<-df1.fam.ra[1,-c(1:15)]
fam.ra.nmr<-df1.fam.ra[2,-c(1:15)]
fam.ra.m.m <- melt(fam.ra.m)
fam.ra.nmr.m <- melt(fam.ra.nmr)
rownames(fam.ra.m.m)<-fam.ra.m.m$variable
rownames(fam.ra.nmr.m)<-fam.ra.nmr.m$variable

d = fortify(phy_tree(ps6.ic.fam))
d = subset(d, isTip)
tip.order<-with(d, label[order(y, decreasing=T)])

fam.ra.m.m<-fam.ra.m.m[match(tip.order, rownames(fam.ra.m.m)), ]
fam.ra.nmr.m<-fam.ra.nmr.m[match(tip.order, rownames(fam.ra.nmr.m)), ]

pdf(file="~Manuscript/Figures/fam.mouse.RA.pdf",
    width=10,height=8,bg = "transparent")
barplot(fam.ra.m.m[,2],horiz=T,width=1,col="#636363",space=0)
dev.off()
plot(phy_tree(ps6.ic.fam))
pdf(file="~Manuscript/Figures/fam.nmr.RA.pdf",
    width=10,height=8,bg = "transparent")
barplot(fam.ra.nmr.m[,2],horiz=T,width=1,col="#636363",space=0)
dev.off()

##### Differential abundance - paired experiment #####
#ASV 
dds.p <-phyloseq_to_deseq2(ps6.p.da, ~ colony + sex + subcaste) # create full model without interactions
dds.p = estimateSizeFactors(dds.p, geoMeans = apply(counts(dds.p), 1, gm_mean))

dds.p.time.pval<-DESeq(dds.p,test="LRT",reduced= ~ colony + sex) # perform LRT to obtain p value #
res.dds.p.time.pval = cbind(as(results(dds.p.time.pval), "data.frame"), as(tax_table(ps6.p.da)[rownames(dds.p.time.pval), ], "matrix"))
res.dds.p.time.pval = cbind(as(results(dds.p.time.pval,contrast=c("subcaste", "T1", "T3")),'data.frame'), as(tax_table(ps6.p.da)[rownames(dds.p.time.pval), ], "matrix"))

dds.p.pair.pval<-DESeq(dds.p,test="LRT",reduced= ~ subcaste + sex) # perform LRT to obtain p value #
res.dds.p.pair.pval = cbind(as(results(dds.p.pair.pval), "data.frame"), as(tax_table(ps6.p.da)[rownames(dds.p.pair.pval), ], "matrix"))

dds.p.sex.pval<-DESeq(dds.p,test="LRT",reduced= ~ colony + sex) # perform LRT to obtain p value #
res.dds.p.sex.pval = cbind(as(results(dds.p.sex.pval), "data.frame"), as(tax_table(ps6.p.da)[rownames(dds.p.sex.pval), ], "matrix"))

dds.p <-phyloseq_to_deseq2(ps6.p.da, ~ colony + sex + subcaste + colony:subcaste +sex:subcaste) # create full model without interactions
dds.p = estimateSizeFactors(dds.p, geoMeans = apply(counts(dds.p), 1, gm_mean))

dds.p.sex.time.pval<-DESeq(dds.p,test="LRT",reduced= ~ colony + sex + subcaste) # perform LRT to obtain p value #
res.dds.p.sex.time.pval = cbind(as(results(dds.p.sex.time.pval), "data.frame"), as(tax_table(ps6.p.da)[rownames(dds.p.sex.time.pval), ], "matrix"))

dds.p.pair.time.pval<-DESeq(dds.p,test="LRT",reduced= ~ colony + sex + subcaste + sex:subcaste) # perform LRT to obtain p value #
res.dds.p.pair.time.pval = cbind(as(results(dds.p.pair.time.pval), "data.frame"), as(tax_table(ps6.p.da)[rownames(dds.p.pair.time.pval), ], "matrix"))


dds.p.t1 <-phyloseq_to_deseq2(ps6.p.t1, ~ sex) # create full model without interactions
dds.p.t1 = estimateSizeFactors(dds.p.t1, geoMeans = apply(counts(dds.p.t1), 1, gm_mean))
dds.p.t1.sex.pval<-DESeq(dds.p.t1,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
res.dds.p.t1.sex.pval = cbind(as(results(dds.p.t1.sex.pval,contrast=c("sex", "female", "male")), "data.frame"), as(tax_table(ps6.p.t1), "matrix"))


dds.p.t3 <-phyloseq_to_deseq2(ps6.p.t3, ~ sex) # create full model without interactions
dds.p.t3 = estimateSizeFactors(dds.p.t3, geoMeans = apply(counts(dds.p.t3), 1, gm_mean))
dds.p.t3.sex.pval<-DESeq(dds.p.t3,test="LRT",reduced= ~ 1) # perform LRT to obtain p value #
res.dds.p.t3.sex.pval = cbind(as(results(dds.p.t3.sex.pval,contrast=c("sex", "female", "male")), "data.frame"), as(tax_table(ps6.p.t3), "matrix"))

res.p<-cbind(as(tax_table(ps6.p.da)[rownames(dds.p), ], "matrix"),
             res.dds.p.time.pval[,6],
             res.dds.p.pair.pval[,6],
             res.dds.p.sex.pval[,c(2,3,6)])
res.p$ASV<-rownames(res.p)

write.csv(res.p,"~Manuscript/deseq.asv.p.csv")

ps.prev<-subset_taxa(ps6.ic, Genus=="Prevotellaceae_UCG-003")
sequences.prev <- Biostrings::DNAStringSet(taxa_names(ps.prev))
names(sequences.prev) <- taxa_names(ps.prev)
ps.prev <- merge_phyloseq(ps.prev, sequences.prev)
p <- ggtree(phy_tree(ps.prev)) + geom_tiplab(size=3.5,align=T)

pdf(file="~Manuscript/Figures/prev.tree.pdf",
    width=10,height=8,bg = "transparent")
ggtree(phy_tree(ps.prev)) + geom_tiplab(size=3.5,align=T)
dev.off()


# relative abundance of prev1 across social groups #
ps.prev.ra<-subset_taxa(ps6.ic.nm.ra, Genus=="Prevotellaceae_UCG-003")
relabund.ps.prev.ra<-cbind(as(sample_data(ps.prev.ra),'data.frame'),as.data.frame(otu_table(ps.prev.ra))) # data frame of phyla abundance and sample data

relabund.prev.subcaste <- relabund.ps.prev.ra %>% group_by(subcaste) %>% summarise_each(funs(mean))
relabund.prev.subcaste<-relabund.prev.subcaste[,-c(2:15)]


pdf(file="~Manuscript/Figures/prev1.subcaste.pdf",
    width=10,height=8,bg = "transparent")
ggplot(data=relabund.prev.subcaste, aes(x=subcaste, y=ASV_2136, fill = subcaste)) +
  geom_bar(stat="identity", color = "black") + 
  scale_fill_manual(values=caste.colors) +
  theme.gg.blankx
dev.off()


#### Linear Rank Data ####
# Elizabeth #
# use el1 #
el1<-read.csv("~TubeTestData/ElizDec12018.csv")
colnames(el1)<-c("ID","pass","percent","rank_1")
el1$rank_z<-(el1$rank_1-mean(el1$rank_1))/sd(el1$rank_1)
el2<-read.csv("~TubeTestData/ElizJuly222019.csv")
colnames(el2)<-c("ID","pass","percent","rank_2")
el3<-read.csv("~TubeTestData/ElizMarch12019.csv")
colnames(el3)<-c("ID","pass","percent","rank_3")

el<-merge(el1, el2, by="ID", all=TRUE) 
el.total<-merge(el, el3, by="ID", all=TRUE) 

cor.test(el.total$rank_1, el.total$rank_2, method=c("spearman")) # p-value = 2.552e-07 rho 0.7188007 
cor.test(el.total$rank_1, el.total$rank_3, method=c("spearman")) # p-value = 5.305e-10 0.807373
cor.test(el.total$rank_2, el.total$rank_3, method=c("spearman")) # p-value < 2.2e-16 0.9335898

ggplot(el.total, aes(x=rank_1, y=rank_2)) +
  geom_point(size=4) +
  theme_classic()

# Fenty #
# use Fenty4 #
Fenty1<-read.csv("~TubeTestData/FentyApril52019.csv")
colnames(Fenty1)<-c("ID","pass_1","percent_1","rank_1")
Fenty2<-read.csv("~TubeTestData/FentyJune52018.csv")
colnames(Fenty2)<-c("ID","pass_2","percent_2","rank_2")
Fenty3<-read.csv("~TubeTestData/FentyMay82018.csv")
colnames(Fenty3)<-c("ID","pass_3","percent_3","rank_3")
Fenty4<-read.csv("~TubeTestData/FentyOct162018.csv")
colnames(Fenty4)<-c("ID","pass_4","percent_4","rank_4")
Fenty4$rank_z<-(Fenty4$rank_4-mean(Fenty4$rank_4))/sd(Fenty4$rank_4)

fenty<-merge(Fenty1, Fenty2, by="ID", all=TRUE) 
fenty1<-merge(fenty, Fenty3, by="ID", all=TRUE) 
fenty.total<-merge(Fenty4, fenty1, by="ID", all=TRUE) 

cor.test(fenty.total$rank_1, fenty.total$rank_2, method=c("spearman")) # p-value = 2.609e-09 rho 0.8981727  
cor.test(fenty.total$rank_1, fenty.total$rank_3, method=c("spearman")) # p-value = 6.682e-07 0.8259359
cor.test(fenty.total$rank_1, fenty.total$rank_4, method=c("spearman")) # p-value 1.114e-11 0.9390778 
cor.test(fenty.total$rank_2, fenty.total$rank_3, method=c("spearman")) # p-value = 2.121e-06 0.8278261 
cor.test(fenty.total$rank_2, fenty.total$rank_4, method=c("spearman")) # p-value 2.702e-06 0.8965217 
cor.test(fenty.total$rank_3, fenty.total$rank_4, method=c("spearman")) # p-value 7.895e-06 0.7878261  

ggplot(fenty.total, aes(x=rank_1, y=rank_2)) +
  geom_point(size=4) +
  theme_classic()

# Ichabod #
# use Ich2 #
Ichabod1<-read.csv("~TubeTestData/IchJune152018.csv")
colnames(Ichabod1)<-c("ID","pass_1","percent_1","rank_1")
Ichabod2<-read.csv("~TubeTestData/IchNov262018.csv")
colnames(Ichabod2)<-c("ID","pass_2","percent_2","rank_2")

Ichabod.total<-merge(Ichabod1, Ichabod2, by="ID", all=TRUE) 

cor.test(Ichabod.total$rank_1, Ichabod.total$rank_2, method=c("spearman")) # p-value = 2.352e-13 rho 0.9419672   

ggplot(Ichabod.total, aes(x=rank_1, y=rank_2)) +
  geom_point(size=4) +
  theme_classic()

# Lucy #
# use lucy1 #
Lucy1<-read.csv("~TubeTestData/LucAug222018.csv")
colnames(Lucy1)<-c("ID","pass_1","percent_1","rank_1")
Lucy2<-read.csv("~TubeTestData/LucJune62018.csv")
colnames(Lucy2)<-c("ID","pass_2","percent_2","rank_2")

Lucy.total<-merge(Lucy1, Lucy2, by="ID", all=TRUE) 

cor.test(Lucy.total$rank_1, Lucy.total$rank_2, method=c("spearman")) # p-value = 2.07e-12 rho 0.9422199   

ggplot(Lucy.total, aes(x=rank_1, y=rank_2)) +
  geom_point(size=4) +
  theme_classic()

# Macbeth #
# use Macbeth 3 #
Macbeth1<-read.csv("~TubeTestData/MacApril252018.csv")
colnames(Macbeth1)<-c("ID","pass_1","percent_1","rank_1")
Macbeth2<-read.csv("~TubeTestData/MacFeb262019.csv")
colnames(Macbeth2)<-c("ID","pass_2","percent_2","rank_2")
Macbeth3<-read.csv("~TubeTestData/MacSept272018.csv")
colnames(Macbeth3)<-c("ID","pass_3","percent_3","rank_3")

Macbeth<-merge(Macbeth1, Macbeth2, by="ID", all=TRUE) 
Macbeth.total<-merge(Macbeth, Macbeth3, by="ID", all=TRUE) 

cor.test(Macbeth.total$rank_1, Macbeth.total$rank_2, method=c("spearman")) # p-value = 5.924e-12 rho 0.8996476 
cor.test(Macbeth.total$rank_1, Macbeth.total$rank_3, method=c("spearman")) # p-value = 2.037e-11 0.916131
cor.test(Macbeth.total$rank_2, Macbeth.total$rank_3, method=c("spearman")) # p-value 2.028e-11 0.9355682

# Xena #
# use Xena 1 #
Xena1<-read.csv("~TubeTestData/XenaAug312018.csv")
colnames(Xena1)<-c("ID","pass_1","percent_1","rank_1")
Xena2<-read.csv("~TubeTestData/XenaMay292019.csv")
colnames(Xena2)<-c("ID","pass_2","percent_2","rank_2")

Xena.total<-merge(Xena1, Xena2, by="ID", all=TRUE) 

cor.test(Xena.total$rank_1, Xena.total$rank_2, method=c("spearman")) # p-value 1.969e-08 rho 0.8675907   

ggplot(Xena.total, aes(x=rank_1, y=rank_2)) +
  geom_point(size=4) +
  theme_classic()

##### Supplemental Figures/Tables ####
##### Bacterial Family Rel. Abund Host Species ####
ps6.ic.ra.fam<-tax_glom(ps6.ic.ra,taxrank="Family")
taxa_names(ps6.ic.ra.fam)<-as.data.frame(tax_table(ps6.ic.ra.fam)[,5])$Family   # update taxa names
relabund.fam.m<-cbind(as(sample_data(ps6.ic.ra.fam),'data.frame'),as.data.frame(otu_table(ps6.ic.ra.fam))) # data frame of phyla abundance and sample data

spe.fam.df <- relabund.fam.m %>% group_by(spe) %>% summarise_each(funs(mean))
spe.fam.df<-spe.fam.df[,-c(2:15)]

m.spe.fam.df <- melt(spe.fam.df, id.vars = "spe")

write.csv(m.spe.fam.df, "~Manuscript/fam.rel.abund.csv")
write.csv(as(tax_table(ps6.ic.ra.fam), "matrix"), "~Manuscript/fam.class.csv")

